@@ -25,6 +25,7 @@ from __future__ import annotations
 import copy
 import datetime
 import hashlib
+import logging
 import os
 import re
 import uuid
@@ -40,6 +41,8 @@ from airflow.kubernetes.pod_generator_deprecated import PodDefaults, PodGenerato
 from airflow.utils import yaml
 from airflow.version import version as airflow_version
 
+log = logging.getLogger(__name__)
+
 MAX_LABEL_LEN = 63
 
 
@@ -71,7 +74,7 @@ def datetime_to_label_safe_datestring(datetime_obj: datetime.datetime) -> str:
     :param datetime_obj: datetime.datetime object
     :return: ISO-like string representing the datetime
     """
-    return datetime_obj.isoformat().replace(":", "_").replace('+', '_plus_')
+    return datetime_obj.isoformat().replace(":", "_").replace("+", "_plus_")
 
 
 def label_safe_datestring_to_datetime(string: str) -> datetime.datetime:
@@ -83,7 +86,7 @@ def label_safe_datestring_to_datetime(string: str) -> datetime.datetime:
     :param string: str
     :return: datetime.datetime object
     """
-    return parser.parse(string.replace('_plus_', '+').replace("_", ":"))
+    return parser.parse(string.replace("_plus_", "+").replace("_", ":"))
 
 
 class PodGenerator:
@@ -94,7 +97,7 @@ class PodGenerator:
     Any configuration that is container specific gets applied to
     the first container in the list of containers.
 
-    :param pod: The fully specified pod. Mutually exclusive with `path_or_string`
+    :param pod: The fully specified pod. Mutually exclusive with `pod_template_file`
     :param pod_template_file: Path to YAML file. Mutually exclusive with `pod`
     :param extract_xcom: Whether to bring up a container for xcom
     """
@@ -170,15 +173,15 @@ class PodGenerator:
             return k8s_object
         elif isinstance(k8s_legacy_object, dict):
             warnings.warn(
-                'Using a dictionary for the executor_config is deprecated and will soon be removed.'
+                "Using a dictionary for the executor_config is deprecated and will soon be removed."
                 'please use a `kubernetes.client.models.V1Pod` class with a "pod_override" key'
-                ' instead. ',
+                " instead. ",
                 category=RemovedInAirflow3Warning,
             )
             return PodGenerator.from_legacy_obj(obj)
         else:
             raise TypeError(
-                'Cannot convert a non-kubernetes.client.models.V1Pod object into a KubernetesExecutorConfig'
+                "Cannot convert a non-kubernetes.client.models.V1Pod object into a KubernetesExecutorConfig"
             )
 
     @staticmethod
@@ -194,18 +197,18 @@ class PodGenerator:
         if not namespaced:
             return None
 
-        resources = namespaced.get('resources')
+        resources = namespaced.get("resources")
 
         if resources is None:
             requests = {
-                'cpu': namespaced.pop('request_cpu', None),
-                'memory': namespaced.pop('request_memory', None),
-                'ephemeral-storage': namespaced.get('ephemeral-storage'),  # We pop this one in limits
+                "cpu": namespaced.pop("request_cpu", None),
+                "memory": namespaced.pop("request_memory", None),
+                "ephemeral-storage": namespaced.get("ephemeral-storage"),  # We pop this one in limits
             }
             limits = {
-                'cpu': namespaced.pop('limit_cpu', None),
-                'memory': namespaced.pop('limit_memory', None),
-                'ephemeral-storage': namespaced.pop('ephemeral-storage', None),
+                "cpu": namespaced.pop("limit_cpu", None),
+                "memory": namespaced.pop("limit_memory", None),
+                "ephemeral-storage": namespaced.pop("ephemeral-storage", None),
             }
             all_resources = list(requests.values()) + list(limits.values())
             if all(r is None for r in all_resources):
@@ -215,7 +218,7 @@ class PodGenerator:
                 requests = {k: v for k, v in requests.items() if v is not None}
                 limits = {k: v for k, v in limits.items() if v is not None}
                 resources = k8s.V1ResourceRequirements(requests=requests, limits=limits)
-        namespaced['resources'] = resources
+        namespaced["resources"] = resources
         return PodGeneratorDeprecated(**namespaced).gen_pod()
 
     @staticmethod
@@ -254,9 +257,9 @@ class PodGenerator:
         elif client_meta and base_meta:
             client_meta.labels = merge_objects(base_meta.labels, client_meta.labels)
             client_meta.annotations = merge_objects(base_meta.annotations, client_meta.annotations)
-            extend_object_field(base_meta, client_meta, 'managed_fields')
-            extend_object_field(base_meta, client_meta, 'finalizers')
-            extend_object_field(base_meta, client_meta, 'owner_references')
+            extend_object_field(base_meta, client_meta, "managed_fields")
+            extend_object_field(base_meta, client_meta, "finalizers")
+            extend_object_field(base_meta, client_meta, "owner_references")
             return merge_objects(base_meta, client_meta)
 
         return None
@@ -279,8 +282,8 @@ class PodGenerator:
             client_spec.containers = PodGenerator.reconcile_containers(
                 base_spec.containers, client_spec.containers
             )
-            merged_spec = extend_object_field(base_spec, client_spec, 'init_containers')
-            merged_spec = extend_object_field(base_spec, merged_spec, 'volumes')
+            merged_spec = extend_object_field(base_spec, client_spec, "init_containers")
+            merged_spec = extend_object_field(base_spec, merged_spec, "volumes")
             return merge_objects(base_spec, merged_spec)
 
         return None
@@ -304,11 +307,11 @@ class PodGenerator:
 
         client_container = client_containers[0]
         base_container = base_containers[0]
-        client_container = extend_object_field(base_container, client_container, 'volume_mounts')
-        client_container = extend_object_field(base_container, client_container, 'env')
-        client_container = extend_object_field(base_container, client_container, 'env_from')
-        client_container = extend_object_field(base_container, client_container, 'ports')
-        client_container = extend_object_field(base_container, client_container, 'volume_devices')
+        client_container = extend_object_field(base_container, client_container, "volume_mounts")
+        client_container = extend_object_field(base_container, client_container, "env")
+        client_container = extend_object_field(base_container, client_container, "env_from")
+        client_container = extend_object_field(base_container, client_container, "ports")
+        client_container = extend_object_field(base_container, client_container, "volume_devices")
         client_container = merge_objects(base_container, client_container)
 
         return [client_container] + PodGenerator.reconcile_containers(
@@ -345,27 +348,27 @@ class PodGenerator:
             image = kube_image
 
         annotations = {
-            'dag_id': dag_id,
-            'task_id': task_id,
-            'try_number': str(try_number),
+            "dag_id": dag_id,
+            "task_id": task_id,
+            "try_number": str(try_number),
         }
         labels = {
-            'airflow-worker': make_safe_label_value(scheduler_job_id),
-            'dag_id': make_safe_label_value(dag_id),
-            'task_id': make_safe_label_value(task_id),
-            'try_number': str(try_number),
-            'airflow_version': airflow_version.replace('+', '-'),
-            'kubernetes_executor': 'True',
+            "airflow-worker": make_safe_label_value(scheduler_job_id),
+            "dag_id": make_safe_label_value(dag_id),
+            "task_id": make_safe_label_value(task_id),
+            "try_number": str(try_number),
+            "airflow_version": airflow_version.replace("+", "-"),
+            "kubernetes_executor": "True",
         }
         if map_index >= 0:
-            annotations['map_index'] = str(map_index)
-            labels['map_index'] = str(map_index)
+            annotations["map_index"] = str(map_index)
+            labels["map_index"] = str(map_index)
         if date:
-            annotations['execution_date'] = date.isoformat()
-            labels['execution_date'] = datetime_to_label_safe_datestring(date)
+            annotations["execution_date"] = date.isoformat()
+            labels["execution_date"] = datetime_to_label_safe_datestring(date)
         if run_id:
-            annotations['run_id'] = run_id
-            labels['run_id'] = make_safe_label_value(run_id)
+            annotations["run_id"] = run_id
+            labels["run_id"] = make_safe_label_value(run_id)
 
         dynamic_pod = k8s.V1Pod(
             metadata=k8s.V1ObjectMeta(
@@ -412,24 +415,25 @@ class PodGenerator:
         """
         :param path: Path to the file
         :return: a kubernetes.client.models.V1Pod
-
-        Unfortunately we need access to the private method
-        ``_ApiClient__deserialize_model`` from the kubernetes client.
-        This issue is tracked here; https://github.com/kubernetes-client/python/issues/977.
         """
         if os.path.exists(path):
             with open(path) as stream:
                 pod = yaml.safe_load(stream)
         else:
-            pod = yaml.safe_load(path)
+            pod = None
+            log.warning("Model file %s does not exist", path)
 
         return PodGenerator.deserialize_model_dict(pod)
 
     @staticmethod
-    def deserialize_model_dict(pod_dict: dict) -> k8s.V1Pod:
+    def deserialize_model_dict(pod_dict: dict | None) -> k8s.V1Pod:
         """
         Deserializes python dictionary to k8s.V1Pod
 
+        Unfortunately we need access to the private method
+        ``_ApiClient__deserialize_model`` from the kubernetes client.
+        This issue is tracked here; https://github.com/kubernetes-client/python/issues/977.
+
         :param pod_dict: Serialized dict of k8s.V1Pod object
         :return: De-serialized k8s.V1Pod
         """
@@ -460,7 +464,7 @@ class PodGenerator:
         # Get prefix length after subtracting the uuid length. Clean up '.' and '-' from
         # end of podID ('.' can't be followed by '-').
         label_prefix_length = MAX_LABEL_LEN - len(safe_uuid) - 1  # -1 for separator
-        trimmed_pod_id = pod_id[:label_prefix_length].rstrip('-.')
+        trimmed_pod_id = pod_id[:label_prefix_length].rstrip("-.")
 
         # previously used a '.' as the separator, but this could create errors in some situations
         return f"{trimmed_pod_id}-{safe_uuid}"
