@@ -21,7 +21,7 @@ import json
 import logging
 import warnings
 from json import JSONDecodeError
-from urllib.parse import parse_qsl, quote, unquote, urlencode, urlparse
+from urllib.parse import parse_qsl, quote, unquote, urlencode, urlsplit
 
 from sqlalchemy import Boolean, Column, Integer, String, Text
 from sqlalchemy.ext.declarative import declared_attr
@@ -48,8 +48,8 @@ def parse_netloc_to_hostname(*args, **kwargs):
 # See: https://issues.apache.org/jira/browse/AIRFLOW-3615
 def _parse_netloc_to_hostname(uri_parts):
     """Parse a URI string to get correct Hostname."""
-    hostname = unquote(uri_parts.hostname or '')
-    if '/' in hostname:
+    hostname = unquote(uri_parts.hostname or "")
+    if "/" in hostname:
         hostname = uri_parts.netloc
         if "@" in hostname:
             hostname = hostname.rsplit("@", 1)[1]
@@ -82,22 +82,22 @@ class Connection(Base, LoggingMixin):
     :param uri: URI address describing connection parameters.
     """
 
-    EXTRA_KEY = '__extra__'
+    EXTRA_KEY = "__extra__"
 
     __tablename__ = "connection"
 
     id = Column(Integer(), primary_key=True)
     conn_id = Column(String(ID_LEN), unique=True, nullable=False)
     conn_type = Column(String(500), nullable=False)
-    description = Column(Text().with_variant(Text(5000), 'mysql').with_variant(String(5000), 'sqlite'))
+    description = Column(Text().with_variant(Text(5000), "mysql").with_variant(String(5000), "sqlite"))
     host = Column(String(500))
     schema = Column(String(500))
     login = Column(String(500))
-    _password = Column('password', String(5000))
+    _password = Column("password", String(5000))
     port = Column(Integer())
     is_encrypted = Column(Boolean, unique=False, default=False)
     is_extra_encrypted = Column(Boolean, unique=False, default=False)
-    _extra = Column('extra', Text())
+    _extra = Column("extra", Text())
 
     def __init__(
         self,
@@ -181,14 +181,14 @@ class Connection(Base, LoggingMixin):
 
     @staticmethod
     def _normalize_conn_type(conn_type):
-        if conn_type == 'postgresql':
-            conn_type = 'postgres'
-        elif '-' in conn_type:
-            conn_type = conn_type.replace('-', '_')
+        if conn_type == "postgresql":
+            conn_type = "postgres"
+        elif "-" in conn_type:
+            conn_type = conn_type.replace("-", "_")
         return conn_type
 
     def _parse_from_uri(self, uri: str):
-        uri_parts = urlparse(uri)
+        uri_parts = urlsplit(uri)
         conn_type = uri_parts.scheme
         self.conn_type = self._normalize_conn_type(conn_type)
         self.host = _parse_netloc_to_hostname(uri_parts)
@@ -206,35 +206,38 @@ class Connection(Base, LoggingMixin):
 
     def get_uri(self) -> str:
         """Return connection in URI format"""
-        if '_' in self.conn_type:
+        if self.conn_type and "_" in self.conn_type:
             self.log.warning(
                 "Connection schemes (type: %s) shall not contain '_' according to RFC3986.",
                 self.conn_type,
             )
 
-        uri = f"{str(self.conn_type).lower().replace('_', '-')}://"
+        if self.conn_type:
+            uri = f"{self.conn_type.lower().replace('_', '-')}://"
+        else:
+            uri = "//"
 
-        authority_block = ''
+        authority_block = ""
         if self.login is not None:
-            authority_block += quote(self.login, safe='')
+            authority_block += quote(self.login, safe="")
 
         if self.password is not None:
-            authority_block += ':' + quote(self.password, safe='')
+            authority_block += ":" + quote(self.password, safe="")
 
-        if authority_block > '':
-            authority_block += '@'
+        if authority_block > "":
+            authority_block += "@"
 
             uri += authority_block
 
-        host_block = ''
+        host_block = ""
         if self.host:
-            host_block += quote(self.host, safe='')
+            host_block += quote(self.host, safe="")
 
         if self.port:
-            if host_block == '' and authority_block == '':
-                host_block += f'@:{self.port}'
+            if host_block == "" and authority_block == "":
+                host_block += f"@:{self.port}"
             else:
-                host_block += f':{self.port}'
+                host_block += f":{self.port}"
 
         if self.schema:
             host_block += f"/{quote(self.schema, safe='')}"
@@ -247,9 +250,9 @@ class Connection(Base, LoggingMixin):
             except TypeError:
                 query = None
             if query and self.extra_dejson == dict(parse_qsl(query, keep_blank_values=True)):
-                uri += ('?' if self.schema else '/?') + query
+                uri += ("?" if self.schema else "/?") + query
             else:
-                uri += ('?' if self.schema else '/?') + urlencode({self.EXTRA_KEY: self.extra})
+                uri += ("?" if self.schema else "/?") + urlencode({self.EXTRA_KEY: self.extra})
 
         return uri
 
@@ -262,7 +265,7 @@ class Connection(Base, LoggingMixin):
                     f"Can't decrypt encrypted password for login={self.login}  "
                     f"FERNET_KEY configuration is missing"
                 )
-            return fernet.decrypt(bytes(self._password, 'utf-8')).decode()
+            return fernet.decrypt(bytes(self._password, "utf-8")).decode()
         else:
             return self._password
 
@@ -270,15 +273,15 @@ class Connection(Base, LoggingMixin):
         """Encrypt password and set in object attribute."""
         if value:
             fernet = get_fernet()
-            self._password = fernet.encrypt(bytes(value, 'utf-8')).decode()
+            self._password = fernet.encrypt(bytes(value, "utf-8")).decode()
             self.is_encrypted = fernet.is_encrypted
 
     @declared_attr
     def password(cls):
         """Password. The value is decrypted/encrypted when reading/setting the value."""
-        return synonym('_password', descriptor=property(cls.get_password, cls.set_password))
+        return synonym("_password", descriptor=property(cls.get_password, cls.set_password))
 
-    def get_extra(self) -> dict:
+    def get_extra(self) -> str:
         """Return encrypted extra-data."""
         if self._extra and self.is_extra_encrypted:
             fernet = get_fernet()
@@ -287,7 +290,7 @@ class Connection(Base, LoggingMixin):
                     f"Can't decrypt `extra` params for login={self.login}, "
                     f"FERNET_KEY configuration is missing"
                 )
-            extra_val = fernet.decrypt(bytes(self._extra, 'utf-8')).decode()
+            extra_val = fernet.decrypt(bytes(self._extra, "utf-8")).decode()
         else:
             extra_val = self._extra
         if extra_val:
@@ -299,7 +302,7 @@ class Connection(Base, LoggingMixin):
         if value:
             self._validate_extra(value, self.conn_id)
             fernet = get_fernet()
-            self._extra = fernet.encrypt(bytes(value, 'utf-8')).decode()
+            self._extra = fernet.encrypt(bytes(value, "utf-8")).decode()
             self.is_extra_encrypted = fernet.is_encrypted
         else:
             self._extra = value
@@ -308,15 +311,15 @@ class Connection(Base, LoggingMixin):
     @declared_attr
     def extra(cls):
         """Extra data. The value is decrypted/encrypted when reading/setting the value."""
-        return synonym('_extra', descriptor=property(cls.get_extra, cls.set_extra))
+        return synonym("_extra", descriptor=property(cls.get_extra, cls.set_extra))
 
     def rotate_fernet_key(self):
         """Encrypts data with a new key. See: :ref:`security/fernet`"""
         fernet = get_fernet()
         if self._password and self.is_encrypted:
-            self._password = fernet.rotate(self._password.encode('utf-8')).decode()
+            self._password = fernet.rotate(self._password.encode("utf-8")).decode()
         if self._extra and self.is_extra_encrypted:
-            self._extra = fernet.rotate(self._extra.encode('utf-8')).decode()
+            self._extra = fernet.rotate(self._extra.encode("utf-8")).decode()
 
     def get_hook(self, *, hook_params=None):
         """Return hook based on conn_type"""
@@ -341,7 +344,7 @@ class Connection(Base, LoggingMixin):
         return hook_class(**{hook.connection_id_attribute_name: self.conn_id}, **hook_params)
 
     def __repr__(self):
-        return self.conn_id or ''
+        return self.conn_id or ""
 
     def log_info(self):
         """
@@ -379,10 +382,10 @@ class Connection(Base, LoggingMixin):
 
     def test_connection(self):
         """Calls out get_hook method and executes test_connection method on that."""
-        status, message = False, ''
+        status, message = False, ""
         try:
             hook = self.get_hook()
-            if getattr(hook, 'test_connection', False):
+            if getattr(hook, "test_connection", False):
                 status, message = hook.test_connection()
             else:
                 message = (
@@ -424,8 +427,8 @@ class Connection(Base, LoggingMixin):
                     return conn
             except Exception:
                 log.exception(
-                    'Unable to retrieve connection from secrets backend (%s). '
-                    'Checking subsequent secrets backend.',
+                    "Unable to retrieve connection from secrets backend (%s). "
+                    "Checking subsequent secrets backend.",
                     type(secrets_backend).__name__,
                 )
 
@@ -434,16 +437,16 @@ class Connection(Base, LoggingMixin):
     @classmethod
     def from_json(cls, value, conn_id=None) -> Connection:
         kwargs = json.loads(value)
-        extra = kwargs.pop('extra', None)
+        extra = kwargs.pop("extra", None)
         if extra:
-            kwargs['extra'] = extra if isinstance(extra, str) else json.dumps(extra)
-        conn_type = kwargs.pop('conn_type', None)
+            kwargs["extra"] = extra if isinstance(extra, str) else json.dumps(extra)
+        conn_type = kwargs.pop("conn_type", None)
         if conn_type:
-            kwargs['conn_type'] = cls._normalize_conn_type(conn_type)
-        port = kwargs.pop('port', None)
+            kwargs["conn_type"] = cls._normalize_conn_type(conn_type)
+        port = kwargs.pop("port", None)
         if port:
             try:
-                kwargs['port'] = int(port)
+                kwargs["port"] = int(port)
             except ValueError:
                 raise ValueError(f"Expected integer value for `port`, but got {port!r} instead.")
         return Connection(conn_id=conn_id, **kwargs)
