@@ -15,7 +15,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import TYPE_CHECKING, Optional, Sequence
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.airbyte.hooks.airbyte import AirbyteHook
@@ -45,16 +47,16 @@ class AirbyteTriggerSyncOperator(BaseOperator):
         Only used when ``asynchronous`` is False.
     """
 
-    template_fields: Sequence[str] = ('connection_id',)
+    template_fields: Sequence[str] = ("connection_id",)
 
     def __init__(
         self,
         connection_id: str,
         airbyte_conn_id: str = "airbyte_default",
-        asynchronous: Optional[bool] = False,
+        asynchronous: bool | None = False,
         api_version: str = "v1",
         wait_seconds: float = 3,
-        timeout: Optional[float] = 3600,
+        timeout: float | None = 3600,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -65,22 +67,22 @@ class AirbyteTriggerSyncOperator(BaseOperator):
         self.wait_seconds = wait_seconds
         self.asynchronous = asynchronous
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         """Create Airbyte Job and wait to finish"""
         self.hook = AirbyteHook(airbyte_conn_id=self.airbyte_conn_id, api_version=self.api_version)
         job_object = self.hook.submit_sync_connection(connection_id=self.connection_id)
-        self.job_id = job_object.json()['job']['id']
+        self.job_id = job_object.json()["job"]["id"]
 
         self.log.info("Job %s was submitted to Airbyte Server", self.job_id)
         if not self.asynchronous:
-            self.log.info('Waiting for job %s to complete', self.job_id)
+            self.log.info("Waiting for job %s to complete", self.job_id)
             self.hook.wait_for_job(job_id=self.job_id, wait_seconds=self.wait_seconds, timeout=self.timeout)
-            self.log.info('Job %s completed successfully', self.job_id)
+            self.log.info("Job %s completed successfully", self.job_id)
 
         return self.job_id
 
     def on_kill(self):
         """Cancel the job if task is cancelled"""
         if self.job_id:
-            self.log.info('on_kill: cancel the airbyte Job %s', self.job_id)
+            self.log.info("on_kill: cancel the airbyte Job %s", self.job_id)
             self.hook.cancel_job(self.job_id)
