@@ -20,14 +20,14 @@ A client for AWS Batch services
 
 .. seealso::
 
-    - http://boto3.readthedocs.io/en/latest/guide/configuration.html
-    - http://boto3.readthedocs.io/en/latest/reference/services/batch.html
+    - https://boto3.amazonaws.com/v1/documentation/api/latest/guide/configuration.html
+    - https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/batch.html
     - https://docs.aws.amazon.com/batch/latest/APIReference/Welcome.html
 """
-import warnings
+from __future__ import annotations
+
 from random import uniform
 from time import sleep
-from typing import Dict, List, Optional, Union
 
 import botocore.client
 import botocore.exceptions
@@ -48,17 +48,16 @@ class BatchProtocol(Protocol):
     .. seealso::
 
         - https://mypy.readthedocs.io/en/latest/protocols.html
-        - http://boto3.readthedocs.io/en/latest/reference/services/batch.html
+        - https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/batch.html
     """
 
-    def describe_jobs(self, jobs: List[str]) -> Dict:
+    def describe_jobs(self, jobs: list[str]) -> dict:
         """
         Get job descriptions from AWS Batch
 
         :param jobs: a list of JobId to describe
 
         :return: an API response to describe jobs
-        :rtype: Dict
         """
         ...
 
@@ -71,7 +70,6 @@ class BatchProtocol(Protocol):
             model file (typically this is CamelCasing).
 
         :return: a waiter object for the named AWS Batch service
-        :rtype: botocore.waiter.Waiter
 
         .. note::
             AWS Batch might not have any waiters (until botocore PR-1307 is released).
@@ -94,11 +92,11 @@ class BatchProtocol(Protocol):
         jobName: str,
         jobQueue: str,
         jobDefinition: str,
-        arrayProperties: Dict,
-        parameters: Dict,
-        containerOverrides: Dict,
-        tags: Dict,
-    ) -> Dict:
+        arrayProperties: dict,
+        parameters: dict,
+        containerOverrides: dict,
+        tags: dict,
+    ) -> dict:
         """
         Submit a Batch job
 
@@ -117,11 +115,10 @@ class BatchProtocol(Protocol):
         :param tags: the same parameter that boto3 will receive
 
         :return: an API response
-        :rtype: Dict
         """
         ...
 
-    def terminate_job(self, jobId: str, reason: str) -> Dict:
+    def terminate_job(self, jobId: str, reason: str) -> dict:
         """
         Terminate a Batch job
 
@@ -130,7 +127,6 @@ class BatchProtocol(Protocol):
         :param reason: a reason to terminate job ID
 
         :return: an API response
-        :rtype: Dict
         """
         ...
 
@@ -181,36 +177,41 @@ class BatchClientHook(AwsBaseHook):
     DEFAULT_DELAY_MIN = 1
     DEFAULT_DELAY_MAX = 10
 
-    FAILURE_STATE = 'FAILED'
-    SUCCESS_STATE = 'SUCCEEDED'
-    RUNNING_STATE = 'RUNNING'
+    FAILURE_STATE = "FAILED"
+    SUCCESS_STATE = "SUCCEEDED"
+    RUNNING_STATE = "RUNNING"
     INTERMEDIATE_STATES = (
-        'SUBMITTED',
-        'PENDING',
-        'RUNNABLE',
-        'STARTING',
+        "SUBMITTED",
+        "PENDING",
+        "RUNNABLE",
+        "STARTING",
         RUNNING_STATE,
     )
 
+    COMPUTE_ENVIRONMENT_TERMINAL_STATUS = ("VALID", "DELETED")
+    COMPUTE_ENVIRONMENT_INTERMEDIATE_STATUS = ("CREATING", "UPDATING", "DELETING")
+
+    JOB_QUEUE_TERMINAL_STATUS = ("VALID", "DELETED")
+    JOB_QUEUE_INTERMEDIATE_STATUS = ("CREATING", "UPDATING", "DELETING")
+
     def __init__(
-        self, *args, max_retries: Optional[int] = None, status_retries: Optional[int] = None, **kwargs
+        self, *args, max_retries: int | None = None, status_retries: int | None = None, **kwargs
     ) -> None:
         # https://github.com/python/mypy/issues/6799 hence type: ignore
-        super().__init__(client_type='batch', *args, **kwargs)  # type: ignore
+        super().__init__(client_type="batch", *args, **kwargs)  # type: ignore
         self.max_retries = max_retries or self.MAX_RETRIES
         self.status_retries = status_retries or self.STATUS_RETRIES
 
     @property
-    def client(self) -> Union[BatchProtocol, botocore.client.BaseClient]:
+    def client(self) -> BatchProtocol | botocore.client.BaseClient:
         """
         An AWS API client for Batch services.
 
         :return: a boto3 'batch' client for the ``.region_name``
-        :rtype: Union[BatchProtocol, botocore.client.BaseClient]
         """
         return self.conn
 
-    def terminate_job(self, job_id: str, reason: str) -> Dict:
+    def terminate_job(self, job_id: str, reason: str) -> dict:
         """
         Terminate a Batch job
 
@@ -219,7 +220,6 @@ class BatchClientHook(AwsBaseHook):
         :param reason: a reason to terminate job ID
 
         :return: an API response
-        :rtype: Dict
         """
         response = self.get_conn().terminate_job(jobId=job_id, reason=reason)
         self.log.info(response)
@@ -232,7 +232,6 @@ class BatchClientHook(AwsBaseHook):
 
         :param job_id: a Batch job ID
 
-        :rtype: bool
 
         :raises: AirflowException
         """
@@ -251,7 +250,7 @@ class BatchClientHook(AwsBaseHook):
 
         raise AirflowException(f"AWS Batch job ({job_id}) has unknown status: {job}")
 
-    def wait_for_job(self, job_id: str, delay: Union[int, float, None] = None) -> None:
+    def wait_for_job(self, job_id: str, delay: int | float | None = None) -> None:
         """
         Wait for Batch job to complete
 
@@ -266,7 +265,7 @@ class BatchClientHook(AwsBaseHook):
         self.poll_for_job_complete(job_id, delay)
         self.log.info("AWS Batch job (%s) has completed", job_id)
 
-    def poll_for_job_running(self, job_id: str, delay: Union[int, float, None] = None) -> None:
+    def poll_for_job_running(self, job_id: str, delay: int | float | None = None) -> None:
         """
         Poll for job running. The status that indicates a job is running or
         already complete are: 'RUNNING'|'SUCCEEDED'|'FAILED'.
@@ -288,7 +287,7 @@ class BatchClientHook(AwsBaseHook):
         running_status = [self.RUNNING_STATE, self.SUCCESS_STATE, self.FAILURE_STATE]
         self.poll_job_status(job_id, running_status)
 
-    def poll_for_job_complete(self, job_id: str, delay: Union[int, float, None] = None) -> None:
+    def poll_for_job_complete(self, job_id: str, delay: int | float | None = None) -> None:
         """
         Poll for job completion. The status that indicates job completion
         are: 'SUCCEEDED'|'FAILED'.
@@ -306,7 +305,7 @@ class BatchClientHook(AwsBaseHook):
         complete_status = [self.SUCCESS_STATE, self.FAILURE_STATE]
         self.poll_job_status(job_id, complete_status)
 
-    def poll_job_status(self, job_id: str, match_status: List[str]) -> bool:
+    def poll_job_status(self, job_id: str, match_status: list[str]) -> bool:
         """
         Poll for job status using an exponential back-off strategy (with max_retries).
 
@@ -315,7 +314,6 @@ class BatchClientHook(AwsBaseHook):
         :param match_status: a list of job status to match; the Batch job status are:
             'SUBMITTED'|'PENDING'|'RUNNABLE'|'STARTING'|'RUNNING'|'SUCCEEDED'|'FAILED'
 
-        :rtype: bool
 
         :raises: AirflowException
         """
@@ -348,14 +346,13 @@ class BatchClientHook(AwsBaseHook):
             )
             self.delay(pause)
 
-    def get_job_description(self, job_id: str) -> Dict:
+    def get_job_description(self, job_id: str) -> dict:
         """
         Get job description (using status_retries).
 
         :param job_id: a Batch job ID
 
         :return: an API response for describe jobs
-        :rtype: Dict
 
         :raises: AirflowException
         """
@@ -390,7 +387,7 @@ class BatchClientHook(AwsBaseHook):
             self.delay(pause)
 
     @staticmethod
-    def parse_job_description(job_id: str, response: Dict) -> Dict:
+    def parse_job_description(job_id: str, response: dict) -> dict:
         """
         Parse job description to extract description for job_id
 
@@ -399,7 +396,6 @@ class BatchClientHook(AwsBaseHook):
         :param response: an API response for describe jobs
 
         :return: an API response to describe job_id
-        :rtype: Dict
 
         :raises: AirflowException
         """
@@ -410,10 +406,47 @@ class BatchClientHook(AwsBaseHook):
 
         return matching_jobs[0]
 
+    def get_job_awslogs_info(self, job_id: str) -> dict[str, str] | None:
+        """
+        Parse job description to extract AWS CloudWatch information.
+
+        :param job_id: AWS Batch Job ID
+        """
+        job_container_desc = self.get_job_description(job_id=job_id).get("container", {})
+        log_configuration = job_container_desc.get("logConfiguration", {})
+
+        # In case if user select other "logDriver" rather than "awslogs"
+        # than CloudWatch logging should be disabled.
+        # If user not specify anything than expected that "awslogs" will use
+        # with default settings:
+        #   awslogs-group = /aws/batch/job
+        #   awslogs-region = `same as AWS Batch Job region`
+        log_driver = log_configuration.get("logDriver", "awslogs")
+        if log_driver != "awslogs":
+            self.log.warning(
+                "AWS Batch job (%s) uses logDriver (%s). AWS CloudWatch logging disabled.", job_id, log_driver
+            )
+            return None
+
+        awslogs_stream_name = job_container_desc.get("logStreamName")
+        if not awslogs_stream_name:
+            # In case of call this method on very early stage of running AWS Batch
+            # there is possibility than AWS CloudWatch Stream Name not exists yet.
+            # AWS CloudWatch Stream Name also not created in case of misconfiguration.
+            self.log.warning("AWS Batch job (%s) doesn't create AWS CloudWatch Stream.", job_id)
+            return None
+
+        # Try to get user-defined log configuration options
+        log_options = log_configuration.get("options", {})
+
+        return {
+            "awslogs_stream_name": awslogs_stream_name,
+            "awslogs_group": log_options.get("awslogs-group", "/aws/batch/job"),
+            "awslogs_region": log_options.get("awslogs-region", self.conn_region_name),
+        }
+
     @staticmethod
-    def add_jitter(
-        delay: Union[int, float], width: Union[int, float] = 1, minima: Union[int, float] = 0
-    ) -> float:
+    def add_jitter(delay: int | float, width: int | float = 1, minima: int | float = 0) -> float:
         """
         Use delay +/- width for random jitter
 
@@ -432,7 +465,6 @@ class BatchClientHook(AwsBaseHook):
 
         :return: uniform(delay - width, delay + width) jitter
             and it is a non-negative number
-        :rtype: float
         """
         delay = abs(delay)
         width = abs(width)
@@ -442,7 +474,7 @@ class BatchClientHook(AwsBaseHook):
         return uniform(lower, upper)
 
     @staticmethod
-    def delay(delay: Union[int, float, None] = None) -> None:
+    def delay(delay: int | float | None = None) -> None:
         """
         Pause execution for ``delay`` seconds.
 
@@ -470,7 +502,6 @@ class BatchClientHook(AwsBaseHook):
 
         :param tries: Number of tries
 
-        :rtype: float
 
         Examples of behavior:
 
@@ -506,35 +537,3 @@ class BatchClientHook(AwsBaseHook):
         delay = 1 + pow(tries * 0.6, 2)
         delay = min(max_interval, delay)
         return uniform(delay / 3, delay)
-
-
-class AwsBatchProtocol(BatchProtocol, Protocol):
-    """
-    This class is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.hooks.batch.BatchProtocol`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This class is deprecated. "
-            "Please use :class:`airflow.providers.amazon.aws.hooks.batch.BatchProtocol`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
-
-
-class AwsBatchClientHook(BatchClientHook):
-    """
-    This hook is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.hooks.batch.BatchClientHook`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This hook is deprecated. "
-            "Please use :class:`airflow.providers.amazon.aws.hooks.batch.BatchClientHook`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
