@@ -14,8 +14,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
+
 import time
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence
+from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
@@ -89,6 +91,7 @@ class RedshiftCreateClusterOperator(BaseOperator):
         "cluster_type",
         "node_type",
         "number_of_nodes",
+        "vpc_security_group_ids",
     )
     ui_color = "#eeaa11"
     ui_fgcolor = "#ffffff"
@@ -103,32 +106,32 @@ class RedshiftCreateClusterOperator(BaseOperator):
         cluster_type: str = "multi-node",
         db_name: str = "dev",
         number_of_nodes: int = 1,
-        cluster_security_groups: Optional[List[str]] = None,
-        vpc_security_group_ids: Optional[List[str]] = None,
-        cluster_subnet_group_name: Optional[str] = None,
-        availability_zone: Optional[str] = None,
-        preferred_maintenance_window: Optional[str] = None,
-        cluster_parameter_group_name: Optional[str] = None,
+        cluster_security_groups: list[str] | None = None,
+        vpc_security_group_ids: list[str] | None = None,
+        cluster_subnet_group_name: str | None = None,
+        availability_zone: str | None = None,
+        preferred_maintenance_window: str | None = None,
+        cluster_parameter_group_name: str | None = None,
         automated_snapshot_retention_period: int = 1,
-        manual_snapshot_retention_period: Optional[int] = None,
+        manual_snapshot_retention_period: int | None = None,
         port: int = 5439,
         cluster_version: str = "1.0",
         allow_version_upgrade: bool = True,
         publicly_accessible: bool = True,
         encrypted: bool = False,
-        hsm_client_certificate_identifier: Optional[str] = None,
-        hsm_configuration_identifier: Optional[str] = None,
-        elastic_ip: Optional[str] = None,
-        tags: Optional[List[Any]] = None,
-        kms_key_id: Optional[str] = None,
+        hsm_client_certificate_identifier: str | None = None,
+        hsm_configuration_identifier: str | None = None,
+        elastic_ip: str | None = None,
+        tags: list[Any] | None = None,
+        kms_key_id: str | None = None,
         enhanced_vpc_routing: bool = False,
-        additional_info: Optional[str] = None,
-        iam_roles: Optional[List[str]] = None,
-        maintenance_track_name: Optional[str] = None,
-        snapshot_schedule_identifier: Optional[str] = None,
-        availability_zone_relocation: Optional[bool] = None,
-        aqua_configuration_status: Optional[str] = None,
-        default_iam_role_arn: Optional[str] = None,
+        additional_info: str | None = None,
+        iam_roles: list[str] | None = None,
+        maintenance_track_name: str | None = None,
+        snapshot_schedule_identifier: str | None = None,
+        availability_zone_relocation: bool | None = None,
+        aqua_configuration_status: str | None = None,
+        default_iam_role_arn: str | None = None,
         aws_conn_id: str = "aws_default",
         **kwargs,
     ):
@@ -169,10 +172,10 @@ class RedshiftCreateClusterOperator(BaseOperator):
         self.aws_conn_id = aws_conn_id
         self.kwargs = kwargs
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         redshift_hook = RedshiftHook(aws_conn_id=self.aws_conn_id)
         self.log.info("Creating Redshift cluster %s", self.cluster_identifier)
-        params: Dict[str, Any] = {}
+        params: dict[str, Any] = {}
         if self.db_name:
             params["DBName"] = self.db_name
         if self.cluster_type:
@@ -262,6 +265,11 @@ class RedshiftCreateClusterSnapshotOperator(BaseOperator):
         The default connection id is ``aws_default``
     """
 
+    template_fields: Sequence[str] = (
+        "cluster_identifier",
+        "snapshot_identifier",
+    )
+
     def __init__(
         self,
         *,
@@ -283,7 +291,7 @@ class RedshiftCreateClusterSnapshotOperator(BaseOperator):
         self.max_attempt = max_attempt
         self.redshift_hook = RedshiftHook(aws_conn_id=aws_conn_id)
 
-    def execute(self, context: "Context") -> Any:
+    def execute(self, context: Context) -> Any:
         cluster_state = self.redshift_hook.cluster_status(cluster_identifier=self.cluster_identifier)
         if cluster_state != "available":
             raise AirflowException(
@@ -300,7 +308,6 @@ class RedshiftCreateClusterSnapshotOperator(BaseOperator):
         if self.wait_for_completion:
             self.redshift_hook.get_conn().get_waiter("snapshot_available").wait(
                 ClusterIdentifier=self.cluster_identifier,
-                SnapshotIdentifier=self.snapshot_identifier,
                 WaiterConfig={
                     "Delay": self.poll_interval,
                     "MaxAttempts": self.max_attempt,
@@ -325,6 +332,11 @@ class RedshiftDeleteClusterSnapshotOperator(BaseOperator):
     :param poll_interval: Time (in seconds) to wait between two consecutive calls to check snapshot state
     """
 
+    template_fields: Sequence[str] = (
+        "cluster_identifier",
+        "snapshot_identifier",
+    )
+
     def __init__(
         self,
         *,
@@ -342,7 +354,7 @@ class RedshiftDeleteClusterSnapshotOperator(BaseOperator):
         self.poll_interval = poll_interval
         self.redshift_hook = RedshiftHook(aws_conn_id=aws_conn_id)
 
-    def execute(self, context: "Context") -> Any:
+    def execute(self, context: Context) -> Any:
         self.redshift_hook.get_conn().delete_cluster_snapshot(
             SnapshotClusterIdentifier=self.cluster_identifier,
             SnapshotIdentifier=self.snapshot_identifier,
@@ -355,7 +367,6 @@ class RedshiftDeleteClusterSnapshotOperator(BaseOperator):
     def get_status(self) -> str:
         return self.redshift_hook.get_cluster_snapshot_status(
             snapshot_identifier=self.snapshot_identifier,
-            cluster_identifier=self.cluster_identifier,
         )
 
 
@@ -385,17 +396,27 @@ class RedshiftResumeClusterOperator(BaseOperator):
         super().__init__(**kwargs)
         self.cluster_identifier = cluster_identifier
         self.aws_conn_id = aws_conn_id
+        # These parameters are added to address an issue with the boto3 API where the API
+        # prematurely reports the cluster as available to receive requests. This causes the cluster
+        # to reject initial attempts to resume the cluster despite reporting the correct state.
+        self._attempts = 10
+        self._attempt_interval = 15
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         redshift_hook = RedshiftHook(aws_conn_id=self.aws_conn_id)
-        cluster_state = redshift_hook.cluster_status(cluster_identifier=self.cluster_identifier)
-        if cluster_state == 'paused':
-            self.log.info("Starting Redshift cluster %s", self.cluster_identifier)
-            redshift_hook.get_conn().resume_cluster(ClusterIdentifier=self.cluster_identifier)
-        else:
-            self.log.warning(
-                "Unable to resume cluster since cluster is currently in status: %s", cluster_state
-            )
+
+        while self._attempts >= 1:
+            try:
+                redshift_hook.get_conn().resume_cluster(ClusterIdentifier=self.cluster_identifier)
+                return
+            except redshift_hook.get_conn().exceptions.InvalidClusterStateFault as error:
+                self._attempts = self._attempts - 1
+
+                if self._attempts > 0:
+                    self.log.error("Unable to resume cluster. %d attempts remaining.", self._attempts)
+                    time.sleep(self._attempt_interval)
+                else:
+                    raise error
 
 
 class RedshiftPauseClusterOperator(BaseOperator):
@@ -424,17 +445,27 @@ class RedshiftPauseClusterOperator(BaseOperator):
         super().__init__(**kwargs)
         self.cluster_identifier = cluster_identifier
         self.aws_conn_id = aws_conn_id
+        # These parameters are added to address an issue with the boto3 API where the API
+        # prematurely reports the cluster as available to receive requests. This causes the cluster
+        # to reject initial attempts to pause the cluster despite reporting the correct state.
+        self._attempts = 10
+        self._attempt_interval = 15
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         redshift_hook = RedshiftHook(aws_conn_id=self.aws_conn_id)
-        cluster_state = redshift_hook.cluster_status(cluster_identifier=self.cluster_identifier)
-        if cluster_state == 'available':
-            self.log.info("Pausing Redshift cluster %s", self.cluster_identifier)
-            redshift_hook.get_conn().pause_cluster(ClusterIdentifier=self.cluster_identifier)
-        else:
-            self.log.warning(
-                "Unable to pause cluster since cluster is currently in status: %s", cluster_state
-            )
+
+        while self._attempts >= 1:
+            try:
+                redshift_hook.get_conn().pause_cluster(ClusterIdentifier=self.cluster_identifier)
+                return
+            except redshift_hook.get_conn().exceptions.InvalidClusterStateFault as error:
+                self._attempts = self._attempts - 1
+
+                if self._attempts > 0:
+                    self.log.error("Unable to pause cluster. %d attempts remaining.", self._attempts)
+                    time.sleep(self._attempt_interval)
+                else:
+                    raise error
 
 
 class RedshiftDeleteClusterOperator(BaseOperator):
@@ -463,7 +494,7 @@ class RedshiftDeleteClusterOperator(BaseOperator):
         *,
         cluster_identifier: str,
         skip_final_cluster_snapshot: bool = True,
-        final_cluster_snapshot_identifier: Optional[str] = None,
+        final_cluster_snapshot_identifier: str | None = None,
         wait_for_completion: bool = True,
         aws_conn_id: str = "aws_default",
         poll_interval: float = 30.0,
@@ -477,24 +508,16 @@ class RedshiftDeleteClusterOperator(BaseOperator):
         self.redshift_hook = RedshiftHook(aws_conn_id=aws_conn_id)
         self.poll_interval = poll_interval
 
-    def execute(self, context: 'Context'):
-        self.delete_cluster()
-
-        if self.wait_for_completion:
-            cluster_status: str = self.check_status()
-            while cluster_status != "cluster_not_found":
-                self.log.info(
-                    "cluster status is %s. Sleeping for %s seconds.", cluster_status, self.poll_interval
-                )
-                time.sleep(self.poll_interval)
-                cluster_status = self.check_status()
-
-    def delete_cluster(self) -> None:
+    def execute(self, context: Context):
         self.redshift_hook.delete_cluster(
             cluster_identifier=self.cluster_identifier,
             skip_final_cluster_snapshot=self.skip_final_cluster_snapshot,
             final_cluster_snapshot_identifier=self.final_cluster_snapshot_identifier,
         )
 
-    def check_status(self) -> str:
-        return self.redshift_hook.cluster_status(self.cluster_identifier)
+        if self.wait_for_completion:
+            waiter = self.redshift_hook.get_conn().get_waiter("cluster_deleted")
+            waiter.wait(
+                ClusterIdentifier=self.cluster_identifier,
+                WaiterConfig={"Delay": self.poll_interval, "MaxAttempts": 30},
+            )
