@@ -15,9 +15,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
 """Publish message to SNS queue"""
-from typing import TYPE_CHECKING, Optional, Sequence
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.sns import SnsHook
@@ -42,7 +43,7 @@ class SnsPublishOperator(BaseOperator):
         determined automatically)
     """
 
-    template_fields: Sequence[str] = ('target_arn', 'message', 'subject', 'message_attributes', 'aws_conn_id')
+    template_fields: Sequence[str] = ("target_arn", "message", "subject", "message_attributes", "aws_conn_id")
     template_ext: Sequence[str] = ()
     template_fields_renderers = {"message_attributes": "json"}
 
@@ -51,9 +52,9 @@ class SnsPublishOperator(BaseOperator):
         *,
         target_arn: str,
         message: str,
-        subject: Optional[str] = None,
-        message_attributes: Optional[dict] = None,
-        aws_conn_id: str = 'aws_default',
+        subject: str | None = None,
+        message_attributes: dict | None = None,
+        aws_conn_id: str = "aws_default",
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -63,11 +64,11 @@ class SnsPublishOperator(BaseOperator):
         self.message_attributes = message_attributes
         self.aws_conn_id = aws_conn_id
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         sns = SnsHook(aws_conn_id=self.aws_conn_id)
 
         self.log.info(
-            'Sending SNS notification to %s using %s:\nsubject=%s\nattributes=%s\nmessage=%s',
+            "Sending SNS notification to %s using %s:\nsubject=%s\nattributes=%s\nmessage=%s",
             self.target_arn,
             self.aws_conn_id,
             self.subject,
