@@ -14,8 +14,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
-from typing import TYPE_CHECKING, Iterable, List, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Iterable, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
@@ -27,7 +28,7 @@ if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-AVAILABLE_METHODS = ['APPEND', 'REPLACE', 'UPSERT']
+AVAILABLE_METHODS = ["APPEND", "REPLACE", "UPSERT"]
 
 
 class S3ToRedshiftOperator(BaseOperator):
@@ -63,9 +64,17 @@ class S3ToRedshiftOperator(BaseOperator):
     :param upsert_keys: List of fields to use as key on upsert action
     """
 
-    template_fields: Sequence[str] = ('s3_bucket', 's3_key', 'schema', 'table', 'column_list', 'copy_options')
+    template_fields: Sequence[str] = (
+        "s3_bucket",
+        "s3_key",
+        "schema",
+        "table",
+        "column_list",
+        "copy_options",
+        "redshift_conn_id",
+    )
     template_ext: Sequence[str] = ()
-    ui_color = '#99e699'
+    ui_color = "#99e699"
 
     def __init__(
         self,
@@ -74,14 +83,14 @@ class S3ToRedshiftOperator(BaseOperator):
         table: str,
         s3_bucket: str,
         s3_key: str,
-        redshift_conn_id: str = 'redshift_default',
-        aws_conn_id: str = 'aws_default',
-        verify: Optional[Union[bool, str]] = None,
-        column_list: Optional[List[str]] = None,
-        copy_options: Optional[List] = None,
+        redshift_conn_id: str = "redshift_default",
+        aws_conn_id: str = "aws_default",
+        verify: bool | str | None = None,
+        column_list: list[str] | None = None,
+        copy_options: list | None = None,
         autocommit: bool = False,
-        method: str = 'APPEND',
-        upsert_keys: Optional[List[str]] = None,
+        method: str = "APPEND",
+        upsert_keys: list[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -99,10 +108,10 @@ class S3ToRedshiftOperator(BaseOperator):
         self.upsert_keys = upsert_keys
 
         if self.method not in AVAILABLE_METHODS:
-            raise AirflowException(f'Method not found! Available methods: {AVAILABLE_METHODS}')
+            raise AirflowException(f"Method not found! Available methods: {AVAILABLE_METHODS}")
 
     def _build_copy_query(self, copy_destination: str, credentials_block: str, copy_options: str) -> str:
-        column_names = "(" + ", ".join(self.column_list) + ")" if self.column_list else ''
+        column_names = "(" + ", ".join(self.column_list) + ")" if self.column_list else ""
         return f"""
                     COPY {copy_destination} {column_names}
                     FROM 's3://{self.s3_bucket}/{self.s3_key}'
@@ -111,34 +120,34 @@ class S3ToRedshiftOperator(BaseOperator):
                     {copy_options};
         """
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         redshift_hook = RedshiftSQLHook(redshift_conn_id=self.redshift_conn_id)
         conn = S3Hook.get_connection(conn_id=self.aws_conn_id)
 
-        if conn.extra_dejson.get('role_arn', False):
+        if conn.extra_dejson.get("role_arn", False):
             credentials_block = f"aws_iam_role={conn.extra_dejson['role_arn']}"
         else:
             s3_hook = S3Hook(aws_conn_id=self.aws_conn_id, verify=self.verify)
             credentials = s3_hook.get_credentials()
             credentials_block = build_credentials_block(credentials)
 
-        copy_options = '\n\t\t\t'.join(self.copy_options)
-        destination = f'{self.schema}.{self.table}'
-        copy_destination = f'#{self.table}' if self.method == 'UPSERT' else destination
+        copy_options = "\n\t\t\t".join(self.copy_options)
+        destination = f"{self.schema}.{self.table}"
+        copy_destination = f"#{self.table}" if self.method == "UPSERT" else destination
 
         copy_statement = self._build_copy_query(copy_destination, credentials_block, copy_options)
 
-        sql: Union[str, Iterable[str]]
+        sql: str | Iterable[str]
 
-        if self.method == 'REPLACE':
+        if self.method == "REPLACE":
             sql = ["BEGIN;", f"DELETE FROM {destination};", copy_statement, "COMMIT"]
-        elif self.method == 'UPSERT':
+        elif self.method == "UPSERT":
             keys = self.upsert_keys or redshift_hook.get_table_primary_key(self.table, self.schema)
             if not keys:
                 raise AirflowException(
                     f"No primary key on {self.schema}.{self.table}. Please provide keys on 'upsert_keys'"
                 )
-            where_statement = ' AND '.join([f'{self.table}.{k} = {copy_destination}.{k}' for k in keys])
+            where_statement = " AND ".join([f"{self.table}.{k} = {copy_destination}.{k}" for k in keys])
 
             sql = [
                 f"CREATE TABLE {copy_destination} (LIKE {destination});",
@@ -152,6 +161,6 @@ class S3ToRedshiftOperator(BaseOperator):
         else:
             sql = copy_statement
 
-        self.log.info('Executing COPY command...')
+        self.log.info("Executing COPY command...")
         redshift_hook.run(sql, autocommit=self.autocommit)
         self.log.info("COPY command complete...")
