@@ -15,6 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
+
 import warnings
 
 from airflow.providers.common.sql.operators.sql import SQLCheckOperator
@@ -26,7 +28,7 @@ class DruidCheckOperator(SQLCheckOperator):
     Please use `airflow.providers.common.sql.operators.sql.SQLCheckOperator`.
     """
 
-    def __init__(self, druid_broker_conn_id: str = 'druid_broker_default', **kwargs):
+    def __init__(self, druid_broker_conn_id: str = "druid_broker_default", **kwargs):
         warnings.warn(
             """This class is deprecated.
             Please use `airflow.providers.common.sql.operators.sql.SQLCheckOperator`.""",
