@@ -15,6 +15,8 @@
 # specific language governing permissions and limitations
 # under the License.
 """Launches PODs"""
+from __future__ import annotations
+
 import json
 import math
 import time
@@ -22,7 +24,7 @@ import warnings
 from contextlib import closing
 from dataclasses import dataclass
 from datetime import datetime
-from typing import TYPE_CHECKING, Iterable, Optional, Tuple, cast
+from typing import TYPE_CHECKING, Iterable, cast
 
 import pendulum
 import tenacity
@@ -60,10 +62,10 @@ class PodPhase:
     See https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#pod-phase.
     """
 
-    PENDING = 'Pending'
-    RUNNING = 'Running'
-    FAILED = 'Failed'
-    SUCCEEDED = 'Succeeded'
+    PENDING = "Pending"
+    RUNNING = "Running"
+    FAILED = "Failed"
+    SUCCEEDED = "Succeeded"
 
     terminal_states = {FAILED, SUCCEEDED}
 
@@ -76,7 +78,7 @@ def container_is_running(pod: V1Pod, container_name: str) -> bool:
     container_statuses = pod.status.container_statuses if pod and pod.status else None
     if not container_statuses:
         return False
-    container_status = next(iter([x for x in container_statuses if x.name == container_name]), None)
+    container_status = next((x for x in container_statuses if x.name == container_name), None)
     if not container_status:
         return False
     return container_status.state.running is not None
@@ -85,7 +87,7 @@ def container_is_running(pod: V1Pod, container_name: str) -> bool:
 def get_container_termination_message(pod: V1Pod, container_name: str):
     try:
         container_statuses = pod.status.container_statuses
-        container_status = next(iter([x for x in container_statuses if x.name == container_name]), None)
+        container_status = next((x for x in container_statuses if x.name == container_name), None)
         return container_status.state.terminated.message if container_status else None
     except (AttributeError, TypeError):
         return None
@@ -96,7 +98,7 @@ class PodLoggingStatus:
     """Used for returning the status of the pod and last log time when exiting from `fetch_container_logs`"""
 
     running: bool
-    last_log_time: Optional[DateTime]
+    last_log_time: DateTime | None
 
 
 class PodManager(LoggingMixin):
@@ -109,7 +111,7 @@ class PodManager(LoggingMixin):
         self,
         kube_client: client.CoreV1Api = None,
         in_cluster: bool = True,
-        cluster_context: Optional[str] = None,
+        cluster_context: str | None = None,
     ):
         """
         Creates the launcher.
@@ -119,7 +121,16 @@ class PodManager(LoggingMixin):
         :param cluster_context: context of the cluster
         """
         super().__init__()
-        self._client = kube_client or get_kube_client(in_cluster=in_cluster, cluster_context=cluster_context)
+        if kube_client:
+            self._client = kube_client
+        else:
+            self._client = get_kube_client(in_cluster=in_cluster, cluster_context=cluster_context)
+            warnings.warn(
+                "`kube_client` not supplied to PodManager. "
+                "This will be a required argument in a future release. "
+                "Please use KubernetesHook to create the client before calling.",
+                DeprecationWarning,
+            )
         self._watch = watch.Watch()
 
     def run_pod_async(self, pod: V1Pod, **kwargs) -> V1Pod:
@@ -127,15 +138,15 @@ class PodManager(LoggingMixin):
         sanitized_pod = self._client.api_client.sanitize_for_serialization(pod)
         json_pod = json.dumps(sanitized_pod, indent=2)
 
-        self.log.debug('Pod Creation Request: \n%s', json_pod)
+        self.log.debug("Pod Creation Request: \n%s", json_pod)
         try:
             resp = self._client.create_namespaced_pod(
                 body=sanitized_pod, namespace=pod.metadata.namespace, **kwargs
             )
-            self.log.debug('Pod Creation Response: %s', resp)
+            self.log.debug("Pod Creation Response: %s", resp)
         except Exception as e:
             self.log.exception(
-                'Exception when attempting to create Namespaced Pod: %s', str(json_pod).replace("\n", " ")
+                "Exception when attempting to create Namespaced Pod: %s", str(json_pod).replace("\n", " ")
             )
             raise e
         return resp
@@ -194,14 +205,14 @@ class PodManager(LoggingMixin):
         return self.fetch_container_logs(pod=pod, container_name=container_name, follow=True)
 
     def fetch_container_logs(
-        self, pod: V1Pod, container_name: str, *, follow=False, since_time: Optional[DateTime] = None
+        self, pod: V1Pod, container_name: str, *, follow=False, since_time: DateTime | None = None
     ) -> PodLoggingStatus:
         """
         Follows the logs of container and streams to airflow logging.
         Returns when container exits.
         """
 
-        def consume_logs(*, since_time: Optional[DateTime] = None, follow: bool = True) -> Optional[DateTime]:
+        def consume_logs(*, since_time: DateTime | None = None, follow: bool = True) -> DateTime | None:
             """
             Tries to follow container logs until container completes.
             For a long-running container, sometimes the log read may be interrupted
@@ -221,7 +232,7 @@ class PodManager(LoggingMixin):
                     follow=follow,
                 )
                 for raw_line in logs:
-                    line = raw_line.decode('utf-8', errors="backslashreplace")
+                    line = raw_line.decode("utf-8", errors="backslashreplace")
                     timestamp, message = self.parse_log_line(line)
                     self.log.info(message)
             except BaseHTTPError as e:
@@ -249,7 +260,7 @@ class PodManager(LoggingMixin):
                 return PodLoggingStatus(running=True, last_log_time=last_log_time)
             else:
                 self.log.warning(
-                    'Pod %s log read interrupted but container %s still running',
+                    "Pod %s log read interrupted but container %s still running",
                     pod.metadata.name,
                     container_name,
                 )
@@ -264,25 +275,24 @@ class PodManager(LoggingMixin):
         Monitors a pod and returns the final state
 
         :param pod: pod spec that will be monitored
-        :return:  Tuple[State, Optional[str]]
+        :return: tuple[State, str | None]
         """
         while True:
             remote_pod = self.read_pod(pod)
             if remote_pod.status.phase in PodPhase.terminal_states:
                 break
-            self.log.info('Pod %s has phase %s', pod.metadata.name, remote_pod.status.phase)
+            self.log.info("Pod %s has phase %s", pod.metadata.name, remote_pod.status.phase)
             time.sleep(2)
         return remote_pod
 
-    def parse_log_line(self, line: str) -> Tuple[Optional[DateTime], str]:
+    def parse_log_line(self, line: str) -> tuple[DateTime | None, str]:
         """
         Parse K8s log line and returns the final state
 
         :param line: k8s log line
         :return: timestamp and log message
-        :rtype: Tuple[str, str]
         """
-        split_at = line.find(' ')
+        split_at = line.find(" ")
         if split_at == -1:
             self.log.error(
                 "Error parsing timestamp (no timestamp in message %r). "
@@ -309,18 +319,18 @@ class PodManager(LoggingMixin):
         self,
         pod: V1Pod,
         container_name: str,
-        tail_lines: Optional[int] = None,
+        tail_lines: int | None = None,
         timestamps: bool = False,
-        since_seconds: Optional[int] = None,
+        since_seconds: int | None = None,
         follow=True,
     ) -> Iterable[bytes]:
         """Reads log from the POD"""
         additional_kwargs = {}
         if since_seconds:
-            additional_kwargs['since_seconds'] = since_seconds
+            additional_kwargs["since_seconds"] = since_seconds
 
         if tail_lines:
-            additional_kwargs['tail_lines'] = tail_lines
+            additional_kwargs["tail_lines"] = tail_lines
 
         try:
             return self._client.read_namespaced_pod_log(
@@ -333,18 +343,18 @@ class PodManager(LoggingMixin):
                 **additional_kwargs,
             )
         except BaseHTTPError:
-            self.log.exception('There was an error reading the kubernetes API.')
+            self.log.exception("There was an error reading the kubernetes API.")
             raise
 
     @tenacity.retry(stop=tenacity.stop_after_attempt(3), wait=tenacity.wait_exponential(), reraise=True)
-    def read_pod_events(self, pod: V1Pod) -> "CoreV1EventList":
+    def read_pod_events(self, pod: V1Pod) -> CoreV1EventList:
         """Reads events from the POD"""
         try:
             return self._client.list_namespaced_event(
                 namespace=pod.metadata.namespace, field_selector=f"involvedObject.name={pod.metadata.name}"
             )
         except BaseHTTPError as e:
-            raise AirflowException(f'There was an error reading the kubernetes API: {e}')
+            raise AirflowException(f"There was an error reading the kubernetes API: {e}")
 
     @tenacity.retry(stop=tenacity.stop_after_attempt(3), wait=tenacity.wait_exponential(), reraise=True)
     def read_pod(self, pod: V1Pod) -> V1Pod:
@@ -352,7 +362,7 @@ class PodManager(LoggingMixin):
         try:
             return self._client.read_namespaced_pod(pod.metadata.name, pod.metadata.namespace)
         except BaseHTTPError as e:
-            raise AirflowException(f'There was an error reading the kubernetes API: {e}')
+            raise AirflowException(f"There was an error reading the kubernetes API: {e}")
 
     def await_xcom_sidecar_container_start(self, pod: V1Pod) -> None:
         self.log.info("Checking if xcom sidecar container is started.")
@@ -374,7 +384,7 @@ class PodManager(LoggingMixin):
                 pod.metadata.name,
                 pod.metadata.namespace,
                 container=PodDefaults.SIDECAR_CONTAINER_NAME,
-                command=['/bin/sh'],
+                command=["/bin/sh"],
                 stdin=True,
                 stdout=True,
                 stderr=True,
@@ -384,18 +394,18 @@ class PodManager(LoggingMixin):
         ) as resp:
             result = self._exec_pod_command(
                 resp,
-                f'if [ -s {PodDefaults.XCOM_MOUNT_PATH}/return.json ]; then cat {PodDefaults.XCOM_MOUNT_PATH}/return.json; else echo __airflow_xcom_result_empty__; fi',  # noqa
+                f"if [ -s {PodDefaults.XCOM_MOUNT_PATH}/return.json ]; then cat {PodDefaults.XCOM_MOUNT_PATH}/return.json; else echo __airflow_xcom_result_empty__; fi",  # noqa
             )
-            self._exec_pod_command(resp, 'kill -s SIGINT 1')
+            self._exec_pod_command(resp, "kill -s SIGINT 1")
         if result is None:
-            raise AirflowException(f'Failed to extract xcom from pod: {pod.metadata.name}')
+            raise AirflowException(f"Failed to extract xcom from pod: {pod.metadata.name}")
         return result
 
-    def _exec_pod_command(self, resp, command: str) -> Optional[str]:
+    def _exec_pod_command(self, resp, command: str) -> str | None:
         res = None
         if resp.is_open():
-            self.log.info('Running command... %s\n', command)
-            resp.write_stdin(command + '\n')
+            self.log.info("Running command... %s\n", command)
+            resp.write_stdin(command + "\n")
             while resp.is_open():
                 resp.update(timeout=1)
                 while resp.peek_stdout():
