@@ -14,10 +14,11 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-import warnings
+from __future__ import annotations
+
 from contextlib import closing
 from datetime import datetime
-from typing import Any, Callable, Iterable, List, Mapping, Optional, Tuple, Type, Union
+from typing import Any, Callable, Iterable, Mapping, Sequence, cast
 
 import sqlparse
 from packaging.version import Version
@@ -26,12 +27,10 @@ from typing_extensions import Protocol
 
 from airflow import AirflowException
 from airflow.hooks.base import BaseHook
-from airflow.providers_manager import ProvidersManager
-from airflow.utils.module_loading import import_string
 from airflow.version import version
 
 
-def fetch_all_handler(cursor) -> Optional[List[Tuple]]:
+def fetch_all_handler(cursor) -> list[tuple] | None:
     """Handler for DbApiHook.run() to return results"""
     if cursor.description is not None:
         return cursor.fetchall()
@@ -39,25 +38,12 @@ def fetch_all_handler(cursor) -> Optional[List[Tuple]]:
         return None
 
 
-def _backported_get_hook(connection, *, hook_params=None):
-    """Return hook based on conn_type
-    For supporting Airflow versions < 2.3, we backport "get_hook()" method. This should be removed
-    when "apache-airflow-providers-slack" will depend on Airflow >= 2.3.
-    """
-    hook = ProvidersManager().hooks.get(connection.conn_type, None)
-
-    if hook is None:
-        raise AirflowException(f'Unknown hook type "{connection.conn_type}"')
-    try:
-        hook_class = import_string(hook.hook_class_name)
-    except ImportError:
-        warnings.warn(
-            f"Could not import {hook.hook_class_name} when discovering {hook.hook_name} {hook.package_name}",
-        )
-        raise
-    if hook_params is None:
-        hook_params = {}
-    return hook_class(**{hook.connection_id_attribute_name: connection.conn_id}, **hook_params)
+def fetch_one_handler(cursor) -> list[tuple] | None:
+    """Handler for DbApiHook.run() to return results"""
+    if cursor.description is not None:
+        return cursor.fetchone()
+    else:
+        return None
 
 
 class ConnectorProtocol(Protocol):
@@ -79,14 +65,14 @@ class ConnectorProtocol(Protocol):
 # We want the DbApiHook to derive from the original DbApiHook from airflow, because otherwise
 # SqlSensor and BaseSqlOperator from "airflow.operators" and "airflow.sensors" will refuse to
 # accept the new Hooks as not derived from the original DbApiHook
-if Version(version) < Version('2.4'):
+if Version(version) < Version("2.4"):
     try:
         from airflow.hooks.dbapi import DbApiHook as BaseForDbApiHook
     except ImportError:
         # just in case we have a problem with circular import
-        BaseForDbApiHook: Type[BaseHook] = BaseHook  # type: ignore[no-redef]
+        BaseForDbApiHook: type[BaseHook] = BaseHook  # type: ignore[no-redef]
 else:
-    BaseForDbApiHook: Type[BaseHook] = BaseHook  # type: ignore[no-redef]
+    BaseForDbApiHook: type[BaseHook] = BaseHook  # type: ignore[no-redef]
 
 
 class DbApiHook(BaseForDbApiHook):
@@ -100,19 +86,19 @@ class DbApiHook(BaseForDbApiHook):
     """
 
     # Override to provide the connection name.
-    conn_name_attr = None  # type: str
+    conn_name_attr: str
     # Override to have a default connection id for a particular dbHook
-    default_conn_name = 'default_conn_id'
+    default_conn_name = "default_conn_id"
     # Override if this db supports autocommit.
     supports_autocommit = False
     # Override with the object that exposes the connect method
-    connector = None  # type: Optional[ConnectorProtocol]
+    connector: ConnectorProtocol | None = None
     # Override with db-specific query to check connection
     _test_connection_sql = "select 1"
     # Override with the db-specific value used for placeholders
     placeholder: str = "%s"
 
-    def __init__(self, *args, schema: Optional[str] = None, log_sql: bool = True, **kwargs):
+    def __init__(self, *args, schema: str | None = None, log_sql: bool = True, **kwargs):
         super().__init__()
         if not self.conn_name_attr:
             raise AirflowException("conn_name_attr is not defined")
@@ -125,13 +111,15 @@ class DbApiHook(BaseForDbApiHook):
         # We should not make schema available in deriving hooks for backwards compatibility
         # If a hook deriving from DBApiHook has a need to access schema, then it should retrieve it
         # from kwargs and store it on its own. We do not run "pop" here as we want to give the
-        # Hook deriving from the DBApiHook to still have access to the field in it's constructor
+        # Hook deriving from the DBApiHook to still have access to the field in its constructor
         self.__schema = schema
         self.log_sql = log_sql
+        self.scalar_return_last = False
+        self.last_description: Sequence[Sequence] | None = None
 
     def get_conn(self):
         """Returns a connection object"""
-        db = self.get_connection(getattr(self, self.conn_name_attr))
+        db = self.get_connection(getattr(self, cast(str, self.conn_name_attr)))
         return self.connector.connect(host=db.host, port=db.port, username=db.login, schema=db.schema)
 
     def get_uri(self) -> str:
@@ -198,47 +186,32 @@ class DbApiHook(BaseForDbApiHook):
 
     def get_records(
         self,
-        sql: Union[str, List[str]],
-        parameters: Optional[Union[Iterable, Mapping]] = None,
-        **kwargs: dict,
-    ):
+        sql: str | list[str],
+        parameters: Iterable | Mapping | None = None,
+    ) -> Any:
         """
         Executes the sql and returns a set of records.
 
-        :param sql: the sql statement to be executed (str) or a list of
-            sql statements to execute
+        :param sql: the sql statement to be executed (str) or a list of sql statements to execute
         :param parameters: The parameters to render the SQL query with.
         """
-        with closing(self.get_conn()) as conn:
-            with closing(conn.cursor()) as cur:
-                if parameters is not None:
-                    cur.execute(sql, parameters)
-                else:
-                    cur.execute(sql)
-                return cur.fetchall()
+        return self.run(sql=sql, parameters=parameters, handler=fetch_all_handler)
 
-    def get_first(self, sql: Union[str, List[str]], parameters=None):
+    def get_first(self, sql: str | list[str], parameters: Iterable | Mapping | None = None) -> Any:
         """
         Executes the sql and returns the first resulting row.
 
-        :param sql: the sql statement to be executed (str) or a list of
-            sql statements to execute
+        :param sql: the sql statement to be executed (str) or a list of sql statements to execute
         :param parameters: The parameters to render the SQL query with.
         """
-        with closing(self.get_conn()) as conn:
-            with closing(conn.cursor()) as cur:
-                if parameters is not None:
-                    cur.execute(sql, parameters)
-                else:
-                    cur.execute(sql)
-                return cur.fetchone()
+        return self.run(sql=sql, parameters=parameters, handler=fetch_one_handler)
 
     @staticmethod
     def strip_sql_string(sql: str) -> str:
-        return sql.strip().rstrip(';')
+        return sql.strip().rstrip(";")
 
     @staticmethod
-    def split_sql_string(sql: str) -> List[str]:
+    def split_sql_string(sql: str) -> list[str]:
         """
         Splits string into multiple SQL expressions
 
@@ -246,18 +219,18 @@ class DbApiHook(BaseForDbApiHook):
         :return: list of individual expressions
         """
         splits = sqlparse.split(sqlparse.format(sql, strip_comments=True))
-        statements: List[str] = list(filter(None, splits))
+        statements: list[str] = list(filter(None, splits))
         return statements
 
     def run(
         self,
-        sql: Union[str, Iterable[str]],
+        sql: str | Iterable[str],
         autocommit: bool = False,
-        parameters: Optional[Union[Iterable, Mapping]] = None,
-        handler: Optional[Callable] = None,
+        parameters: Iterable | Mapping | None = None,
+        handler: Callable | None = None,
         split_statements: bool = False,
         return_last: bool = True,
-    ) -> Optional[Union[Any, List[Any]]]:
+    ) -> Any | list[Any] | None:
         """
         Runs a command or a list of commands. Pass a list of sql
         statements to the sql parameter to get them to execute
@@ -273,7 +246,7 @@ class DbApiHook(BaseForDbApiHook):
         :param return_last: Whether to return result for only last statement or for all after split
         :return: return only result of the ALL SQL expressions if handler was provided.
         """
-        scalar_return_last = isinstance(sql, str) and return_last
+        self.scalar_return_last = isinstance(sql, str) and return_last
         if isinstance(sql, str):
             if split_statements:
                 sql = self.split_sql_string(sql)
@@ -297,6 +270,7 @@ class DbApiHook(BaseForDbApiHook):
                     if handler is not None:
                         result = handler(cur)
                         results.append(result)
+                self.last_description = cur.description
 
             # If autocommit was set to False or db does not support autocommit, we do a manual commit.
             if not self.get_autocommit(conn):
@@ -304,7 +278,7 @@ class DbApiHook(BaseForDbApiHook):
 
         if handler is None:
             return None
-        elif scalar_return_last:
+        elif self.scalar_return_last:
             return results[-1]
         else:
             return results
@@ -332,7 +306,7 @@ class DbApiHook(BaseForDbApiHook):
             )
         conn.autocommit = autocommit
 
-    def get_autocommit(self, conn):
+    def get_autocommit(self, conn) -> bool:
         """
         Get autocommit setting for the provided connection.
         Return True if conn.autocommit is set to True.
@@ -341,16 +315,15 @@ class DbApiHook(BaseForDbApiHook):
 
         :param conn: Connection to get autocommit setting from.
         :return: connection autocommit setting.
-        :rtype: bool
         """
-        return getattr(conn, 'autocommit', False) and self.supports_autocommit
+        return getattr(conn, "autocommit", False) and self.supports_autocommit
 
     def get_cursor(self):
         """Returns a cursor"""
         return self.get_conn().cursor()
 
     @classmethod
-    def _generate_insert_sql(cls, table, values, target_fields, replace, **kwargs):
+    def _generate_insert_sql(cls, table, values, target_fields, replace, **kwargs) -> str:
         """
         Helper class method that generates the INSERT SQL statement.
         The REPLACE variant is specific to MySQL syntax.
@@ -360,7 +333,6 @@ class DbApiHook(BaseForDbApiHook):
         :param target_fields: The names of the columns to fill in the table
         :param replace: Whether to replace instead of insert
         :return: The generated INSERT or REPLACE SQL statement
-        :rtype: str
         """
         placeholders = [
             cls.placeholder,
@@ -370,7 +342,7 @@ class DbApiHook(BaseForDbApiHook):
             target_fields = ", ".join(target_fields)
             target_fields = f"({target_fields})"
         else:
-            target_fields = ''
+            target_fields = ""
 
         if not replace:
             sql = "INSERT INTO "
@@ -412,17 +384,16 @@ class DbApiHook(BaseForDbApiHook):
                         self.log.info("Loaded %s rows into %s so far", i, table)
 
             conn.commit()
-        self.log.info("Done loading. Loaded a total of %s rows", i)
+        self.log.info("Done loading. Loaded a total of %s rows into %s", i, table)
 
     @staticmethod
-    def _serialize_cell(cell, conn=None):
+    def _serialize_cell(cell, conn=None) -> str | None:
         """
         Returns the SQL literal of the cell as a string.
 
         :param cell: The cell to insert into the table
         :param conn: The database connection
         :return: The serialized cell
-        :rtype: str
         """
         if cell is None:
             return None
@@ -450,11 +421,11 @@ class DbApiHook(BaseForDbApiHook):
 
     def test_connection(self):
         """Tests the connection using db-specific query"""
-        status, message = False, ''
+        status, message = False, ""
         try:
             if self.get_first(self._test_connection_sql):
                 status = True
-                message = 'Connection successfully tested'
+                message = "Connection successfully tested"
         except Exception as e:
             status = False
             message = str(e)
