@@ -15,25 +15,25 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
 """This module contains Databricks operators."""
+from __future__ import annotations
 
 import csv
 import json
-from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Optional, Sequence, Tuple, Union, cast
+from typing import TYPE_CHECKING, Any, Sequence
 
 from databricks.sql.utils import ParamEscaper
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
-from airflow.providers.common.sql.hooks.sql import fetch_all_handler
+from airflow.providers.common.sql.operators.sql import SQLExecuteQueryOperator
 from airflow.providers.databricks.hooks.databricks_sql import DatabricksSqlHook
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-class DatabricksSqlOperator(BaseOperator):
+class DatabricksSqlOperator(SQLExecuteQueryOperator):
     """
     Executes SQL code in a Databricks SQL endpoint or a Databricks cluster
 
@@ -63,77 +63,80 @@ class DatabricksSqlOperator(BaseOperator):
     :param output_format: format of output data if ``output_path` is specified.
         Possible values are ``csv``, ``json``, ``jsonl``. Default is ``csv``.
     :param csv_params: parameters that will be passed to the ``csv.DictWriter`` class used to write CSV data.
-    :param do_xcom_push: If True, then the result of SQL executed will be pushed to an XCom.
     """
 
     template_fields: Sequence[str] = (
-        'sql',
-        '_output_path',
-        'schema',
-        'catalog',
-        'http_headers',
-        'databricks_conn_id',
+        "sql",
+        "_output_path",
+        "schema",
+        "catalog",
+        "http_headers",
+        "databricks_conn_id",
     )
-    template_ext: Sequence[str] = ('.sql',)
-    template_fields_renderers = {'sql': 'sql'}
+    template_ext: Sequence[str] = (".sql",)
+    template_fields_renderers = {"sql": "sql"}
 
     def __init__(
         self,
         *,
-        sql: Union[str, Iterable[str]],
         databricks_conn_id: str = DatabricksSqlHook.default_conn_name,
-        http_path: Optional[str] = None,
-        sql_endpoint_name: Optional[str] = None,
-        parameters: Optional[Union[Iterable, Mapping]] = None,
+        http_path: str | None = None,
+        sql_endpoint_name: str | None = None,
         session_configuration=None,
-        http_headers: Optional[List[Tuple[str, str]]] = None,
-        catalog: Optional[str] = None,
-        schema: Optional[str] = None,
-        do_xcom_push: bool = False,
-        output_path: Optional[str] = None,
-        output_format: str = 'csv',
-        csv_params: Optional[Dict[str, Any]] = None,
-        client_parameters: Optional[Dict[str, Any]] = None,
+        http_headers: list[tuple[str, str]] | None = None,
+        catalog: str | None = None,
+        schema: str | None = None,
+        output_path: str | None = None,
+        output_format: str = "csv",
+        csv_params: dict[str, Any] | None = None,
+        client_parameters: dict[str, Any] | None = None,
         **kwargs,
     ) -> None:
-        """Creates a new ``DatabricksSqlOperator``."""
-        super().__init__(**kwargs)
+        super().__init__(conn_id=databricks_conn_id, **kwargs)
         self.databricks_conn_id = databricks_conn_id
-        self.sql = sql
-        self._http_path = http_path
-        self._sql_endpoint_name = sql_endpoint_name
         self._output_path = output_path
         self._output_format = output_format
         self._csv_params = csv_params
-        self.parameters = parameters
-        self.do_xcom_push = do_xcom_push
-        self.session_config = session_configuration
+        self.http_path = http_path
+        self.sql_endpoint_name = sql_endpoint_name
+        self.session_configuration = session_configuration
+        self.client_parameters = {} if client_parameters is None else client_parameters
+        self.hook_params = kwargs.pop("hook_params", {})
         self.http_headers = http_headers
         self.catalog = catalog
         self.schema = schema
-        self.client_parameters = client_parameters or {}
 
-    def _get_hook(self) -> DatabricksSqlHook:
-        return DatabricksSqlHook(
-            self.databricks_conn_id,
-            http_path=self._http_path,
-            session_configuration=self.session_config,
-            sql_endpoint_name=self._sql_endpoint_name,
-            http_headers=self.http_headers,
-            catalog=self.catalog,
-            schema=self.schema,
-            caller="DatabricksSqlOperator",
+    def get_db_hook(self) -> DatabricksSqlHook:
+        hook_params = {
+            "http_path": self.http_path,
+            "session_configuration": self.session_configuration,
+            "sql_endpoint_name": self.sql_endpoint_name,
+            "http_headers": self.http_headers,
+            "catalog": self.catalog,
+            "schema": self.schema,
+            "caller": "DatabricksSqlOperator",
             **self.client_parameters,
-        )
+            **self.hook_params,
+        }
+        return DatabricksSqlHook(self.databricks_conn_id, **hook_params)
 
-    def _format_output(self, schema, results):
+    def _process_output(
+        self, results: Any | list[Any], description: Sequence[Sequence] | None, scalar_results: bool
+    ) -> Any:
         if not self._output_path:
-            return
+            return description, results
         if not self._output_format:
             raise AirflowException("Output format should be specified!")
-        field_names = [field[0] for field in schema]
+        if description is None:
+            self.log.warning("Description of the cursor is missing. Will not process the output")
+            return description, results
+        field_names = [field[0] for field in description]
+        if scalar_results:
+            list_results: list[Any] = [results]
+        else:
+            list_results = results
         if self._output_format.lower() == "csv":
-            with open(self._output_path, "w", newline='') as file:
+            with open(self._output_path, "w", newline="") as file:
                 if self._csv_params:
                     csv_params = self._csv_params
                 else:
@@ -144,29 +147,19 @@ class DatabricksSqlOperator(BaseOperator):
                 writer = csv.DictWriter(file, fieldnames=field_names, **csv_params)
                 if write_header:
                     writer.writeheader()
-                for row in results:
+                for row in list_results:
                     writer.writerow(row.asDict())
         elif self._output_format.lower() == "json":
             with open(self._output_path, "w") as file:
-                file.write(json.dumps([row.asDict() for row in results]))
+                file.write(json.dumps([row.asDict() for row in list_results]))
         elif self._output_format.lower() == "jsonl":
             with open(self._output_path, "w") as file:
-                for row in results:
+                for row in list_results:
                     file.write(json.dumps(row.asDict()))
                     file.write("\n")
         else:
             raise AirflowException(f"Unsupported output format: '{self._output_format}'")
-
-    def execute(self, context: 'Context'):
-        self.log.info('Executing: %s', self.sql)
-        hook = self._get_hook()
-        response = hook.run(self.sql, parameters=self.parameters, handler=fetch_all_handler)
-        schema, results = cast(List[Tuple[Any, Any]], response)[0]
-        # self.log.info('Schema: %s', schema)
-        # self.log.info('Results: %s', results)
-        self._format_output(schema, results)
-        if self.do_xcom_push:
-            return results
+        return description, results
 
 
 COPY_INTO_APPROVED_FORMATS = ["CSV", "JSON", "AVRO", "ORC", "PARQUET", "TEXT", "BINARYFILE"]
@@ -215,10 +208,10 @@ class DatabricksCopyIntoOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        '_file_location',
-        '_files',
-        '_table_name',
-        'databricks_conn_id',
+        "_file_location",
+        "_files",
+        "_table_name",
+        "databricks_conn_id",
     )
 
     def __init__(
@@ -228,23 +221,23 @@ class DatabricksCopyIntoOperator(BaseOperator):
         file_location: str,
         file_format: str,
         databricks_conn_id: str = DatabricksSqlHook.default_conn_name,
-        http_path: Optional[str] = None,
-        sql_endpoint_name: Optional[str] = None,
+        http_path: str | None = None,
+        sql_endpoint_name: str | None = None,
         session_configuration=None,
-        http_headers: Optional[List[Tuple[str, str]]] = None,
-        client_parameters: Optional[Dict[str, Any]] = None,
-        catalog: Optional[str] = None,
-        schema: Optional[str] = None,
-        files: Optional[List[str]] = None,
-        pattern: Optional[str] = None,
-        expression_list: Optional[str] = None,
-        credential: Optional[Dict[str, str]] = None,
-        storage_credential: Optional[str] = None,
-        encryption: Optional[Dict[str, str]] = None,
-        format_options: Optional[Dict[str, str]] = None,
-        force_copy: Optional[bool] = None,
-        copy_options: Optional[Dict[str, str]] = None,
-        validate: Optional[Union[bool, int]] = None,
+        http_headers: list[tuple[str, str]] | None = None,
+        client_parameters: dict[str, Any] | None = None,
+        catalog: str | None = None,
+        schema: str | None = None,
+        files: list[str] | None = None,
+        pattern: str | None = None,
+        expression_list: str | None = None,
+        credential: dict[str, str] | None = None,
+        storage_credential: str | None = None,
+        encryption: dict[str, str] | None = None,
+        format_options: dict[str, str] | None = None,
+        force_copy: bool | None = None,
+        copy_options: dict[str, str] | None = None,
+        validate: bool | int | None = None,
         **kwargs,
     ) -> None:
         """Creates a new ``DatabricksSqlOperator``."""
@@ -278,7 +271,7 @@ class DatabricksCopyIntoOperator(BaseOperator):
         self._http_headers = http_headers
         self._client_parameters = client_parameters or {}
         if force_copy is not None:
-            self._copy_options["force"] = 'true' if force_copy else 'false'
+            self._copy_options["force"] = "true" if force_copy else "false"
 
     def _get_hook(self) -> DatabricksSqlHook:
         return DatabricksSqlHook(
@@ -297,7 +290,7 @@ class DatabricksCopyIntoOperator(BaseOperator):
     def _generate_options(
         name: str,
         escaper: ParamEscaper,
-        opts: Optional[Dict[str, str]] = None,
+        opts: dict[str, str] | None = None,
         escape_key: bool = True,
     ) -> str:
         formatted_opts = ""
@@ -357,8 +350,8 @@ FILEFORMAT = {self._file_format}
 """
         return sql.strip()
 
-    def execute(self, context: 'Context') -> Any:
+    def execute(self, context: Context) -> Any:
         sql = self._create_sql_query()
-        self.log.info('Executing: %s', sql)
+        self.log.info("Executing: %s", sql)
         hook = self._get_hook()
         hook.run(sql)
