@@ -25,7 +25,9 @@ Hooks for Cloud Memorystore service.
     pb
     memcache
 """
-from typing import Dict, Optional, Sequence, Tuple, Union
+from __future__ import annotations
+
+from typing import Sequence
 
 from google.api_core import path_template
 from google.api_core.exceptions import NotFound
@@ -71,15 +73,15 @@ class CloudMemorystoreHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
-        self._client: Optional[CloudRedisClient] = None
+        self._client: CloudRedisClient | None = None
 
     def get_conn(self) -> CloudRedisClient:
         """Retrieves client library object that allow access to Cloud Memorystore service."""
@@ -110,11 +112,11 @@ class CloudMemorystoreHook(GoogleBaseHook):
         self,
         location: str,
         instance_id: str,
-        instance: Union[Dict, Instance],
+        instance: dict | Instance,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Creates a Redis instance based on the specified tier and memory size.
@@ -154,7 +156,7 @@ class CloudMemorystoreHook(GoogleBaseHook):
         try:
             self.log.info("Fetching instance: %s", instance_name)
             instance = client.get_instance(
-                request={'name': instance_name}, retry=retry, timeout=timeout, metadata=metadata or ()
+                request={"name": instance_name}, retry=retry, timeout=timeout, metadata=metadata or ()
             )
             self.log.info("Instance exists. Skipping creation.")
             return instance
@@ -164,7 +166,7 @@ class CloudMemorystoreHook(GoogleBaseHook):
         self._append_label(instance, "airflow-version", "v" + version.version)
 
         result = client.create_instance(
-            request={'parent': parent, 'instance_id': instance_id, 'instance': instance},
+            request={"parent": parent, "instance_id": instance_id, "instance": instance},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -172,7 +174,7 @@ class CloudMemorystoreHook(GoogleBaseHook):
         result.result()
         self.log.info("Instance created.")
         return client.get_instance(
-            request={'name': instance_name}, retry=retry, timeout=timeout, metadata=metadata or ()
+            request={"name": instance_name}, retry=retry, timeout=timeout, metadata=metadata or ()
         )
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -181,9 +183,9 @@ class CloudMemorystoreHook(GoogleBaseHook):
         location: str,
         instance: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Deletes a specific Redis instance.  Instance stops serving and data is deleted.
@@ -202,7 +204,7 @@ class CloudMemorystoreHook(GoogleBaseHook):
         name = f"projects/{project_id}/locations/{location}/instances/{instance}"
         self.log.info("Fetching Instance: %s", name)
         instance = client.get_instance(
-            request={'name': name},
+            request={"name": name},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -213,7 +215,7 @@ class CloudMemorystoreHook(GoogleBaseHook):
 
         self.log.info("Deleting Instance: %s", name)
         result = client.delete_instance(
-            request={'name': name},
+            request={"name": name},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -226,11 +228,11 @@ class CloudMemorystoreHook(GoogleBaseHook):
         self,
         location: str,
         instance: str,
-        output_config: Union[Dict, OutputConfig],
+        output_config: dict | OutputConfig,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Export Redis instance data into a Redis RDB format file in Cloud Storage.
@@ -255,7 +257,7 @@ class CloudMemorystoreHook(GoogleBaseHook):
         name = f"projects/{project_id}/locations/{location}/instances/{instance}"
         self.log.info("Exporting Instance: %s", name)
         result = client.export_instance(
-            request={'name': name, 'output_config': output_config},
+            request={"name": name, "output_config": output_config},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -270,9 +272,9 @@ class CloudMemorystoreHook(GoogleBaseHook):
         instance: str,
         data_protection_mode: FailoverInstanceRequest.DataProtectionMode,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Failover of the primary node to current replica node.
@@ -298,7 +300,7 @@ class CloudMemorystoreHook(GoogleBaseHook):
         self.log.info("Failovering Instance: %s", name)
 
         result = client.failover_instance(
-            request={'name': name, 'data_protection_mode': data_protection_mode},
+            request={"name": name, "data_protection_mode": data_protection_mode},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -312,9 +314,9 @@ class CloudMemorystoreHook(GoogleBaseHook):
         location: str,
         instance: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Gets the details of a specific Redis instance.
@@ -332,7 +334,7 @@ class CloudMemorystoreHook(GoogleBaseHook):
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/instances/{instance}"
         result = client.get_instance(
-            request={'name': name},
+            request={"name": name},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -345,11 +347,11 @@ class CloudMemorystoreHook(GoogleBaseHook):
         self,
         location: str,
         instance: str,
-        input_config: Union[Dict, InputConfig],
+        input_config: dict | InputConfig,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Import a Redis RDB snapshot file from Cloud Storage into a Redis instance.
@@ -375,7 +377,7 @@ class CloudMemorystoreHook(GoogleBaseHook):
         name = f"projects/{project_id}/locations/{location}/instances/{instance}"
         self.log.info("Importing Instance: %s", name)
         result = client.import_instance(
-            request={'name': name, 'input_config': input_config},
+            request={"name": name, "input_config": input_config},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -389,9 +391,9 @@ class CloudMemorystoreHook(GoogleBaseHook):
         location: str,
         page_size: int,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         List Redis instances owned by a project at the specified location (region) or all locations.
@@ -414,7 +416,7 @@ class CloudMemorystoreHook(GoogleBaseHook):
         client = self.get_conn()
         parent = f"projects/{project_id}/locations/{location}"
         result = client.list_instances(
-            request={'parent': parent, 'page_size': page_size},
+            request={"parent": parent, "page_size": page_size},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -425,14 +427,14 @@ class CloudMemorystoreHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def update_instance(
         self,
-        update_mask: Union[Dict, FieldMask],
-        instance: Union[Dict, Instance],
+        update_mask: dict | FieldMask,
+        instance: dict | Instance,
         project_id: str = PROVIDE_PROJECT_ID,
-        location: Optional[str] = None,
-        instance_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        location: str | None = None,
+        instance_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Updates the metadata and configuration of a specific Redis instance.
@@ -474,7 +476,7 @@ class CloudMemorystoreHook(GoogleBaseHook):
 
         self.log.info("Updating instances: %s", instance.name)
         result = client.update_instance(
-            request={'update_mask': update_mask, 'instance': instance},
+            request={"update_mask": update_mask, "instance": instance},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -508,19 +510,17 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
-        self._client: Optional[CloudMemcacheClient] = None
+        self._client: CloudMemcacheClient | None = None
 
-    def get_conn(
-        self,
-    ):
+    def get_conn(self):
         """Retrieves client library object that allow access to Cloud Memorystore Memcached service."""
         if not self._client:
             self._client = CloudMemcacheClient(credentials=self.get_credentials())
@@ -552,9 +552,9 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
         project_id: str,
         location: str,
         instance_id: str,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Will update current set of Parameters to the set of specified nodes of the Memcached Instance.
@@ -594,11 +594,11 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
         self,
         location: str,
         instance_id: str,
-        instance: Union[Dict, cloud_memcache.Instance],
+        instance: dict | cloud_memcache.Instance,
         project_id: str,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Creates a Memcached instance based on the specified tier and memory size.
@@ -672,9 +672,9 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
         location: str,
         instance: str,
         project_id: str,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Deletes a specific Memcached instance.  Instance stops serving and data is deleted.
@@ -719,9 +719,9 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
         location: str,
         instance: str,
         project_id: str,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Gets the details of a specific Memcached instance.
@@ -748,9 +748,9 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
         self,
         location: str,
         project_id: str,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         List Memcached instances owned by a project at the specified location (region) or all locations.
@@ -784,14 +784,14 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def update_instance(
         self,
-        update_mask: Union[Dict, FieldMask],
-        instance: Union[Dict, cloud_memcache.Instance],
+        update_mask: dict | FieldMask,
+        instance: dict | cloud_memcache.Instance,
         project_id: str,
-        location: Optional[str] = None,
-        instance_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        location: str | None = None,
+        instance_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Updates the metadata and configuration of a specific Memcached instance.
@@ -803,7 +803,7 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
 
             If a dict is provided, it must be of the same form as the protobuf message
             :class:`~google.protobuf.field_mask_pb2.FieldMask`)
-            Union[Dict, google.protobuf.field_mask_pb2.FieldMask]
+            Union[dict, google.protobuf.field_mask_pb2.FieldMask]
         :param instance: Required. Update description. Only fields specified in ``update_mask`` are updated.
 
             If a dict is provided, it must be of the same form as the protobuf message
@@ -841,14 +841,14 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def update_parameters(
         self,
-        update_mask: Union[Dict, FieldMask],
-        parameters: Union[Dict, cloud_memcache.MemcacheParameters],
+        update_mask: dict | FieldMask,
+        parameters: dict | cloud_memcache.MemcacheParameters,
         project_id: str,
         location: str,
         instance_id: str,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Update the defined Memcached Parameters for an existing Instance.
@@ -859,7 +859,6 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
         :param update_mask: Required. Mask of fields to update.
             If a dict is provided, it must be of the same form as the protobuf message
             :class:`~google.protobuf.field_mask_pb2.FieldMask`
-            Union[Dict, google.protobuf.field_mask_pb2.FieldMask]
         :param parameters: The parameters to apply to the instance.
             If a dict is provided, it must be of the same form as the protobuf message
             :class:`~google.cloud.memcache_v1beta2.types.cloud_memcache.MemcacheParameters`
