@@ -14,12 +14,13 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """This module contains Google DataFusion hook."""
+from __future__ import annotations
+
 import json
 import os
 from time import monotonic, sleep
-from typing import Any, Dict, List, Optional, Sequence, Union
+from typing import Any, Dict, Sequence
 from urllib.parse import quote, urlencode
 
 import google.auth
@@ -53,14 +54,14 @@ SUCCESS_STATES = [PipelineStates.COMPLETED]
 class DataFusionHook(GoogleBaseHook):
     """Hook for Google DataFusion."""
 
-    _conn = None  # type: Optional[Resource]
+    _conn: Resource | None = None
 
     def __init__(
         self,
         api_version: str = "v1beta1",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
@@ -69,7 +70,7 @@ class DataFusionHook(GoogleBaseHook):
         )
         self.api_version = api_version
 
-    def wait_for_operation(self, operation: Dict[str, Any]) -> Dict[str, Any]:
+    def wait_for_operation(self, operation: dict[str, Any]) -> dict[str, Any]:
         """Waits for long-lasting operation to complete."""
         for time_to_wait in exponential_sleep_generator(initial=10, maximum=120):
             sleep(time_to_wait)
@@ -88,8 +89,8 @@ class DataFusionHook(GoogleBaseHook):
         pipeline_id: str,
         instance_url: str,
         namespace: str = "default",
-        success_states: Optional[List[str]] = None,
-        failure_states: Optional[List[str]] = None,
+        success_states: list[str] | None = None,
+        failure_states: list[str] | None = None,
         timeout: int = 5 * 60,
     ) -> None:
         """
@@ -138,9 +139,9 @@ class DataFusionHook(GoogleBaseHook):
         return os.path.join(instance_url, "v3", "namespaces", quote(namespace), "apps")
 
     def _cdap_request(
-        self, url: str, method: str, body: Optional[Union[List, Dict]] = None
+        self, url: str, method: str, body: list | dict | None = None
     ) -> google.auth.transport.Response:
-        headers: Dict[str, str] = {"Content-Type": "application/json"}
+        headers: dict[str, str] = {"Content-Type": "application/json"}
         request = google.auth.transport.requests.Request()
 
         credentials = self.get_credentials()
@@ -151,6 +152,16 @@ class DataFusionHook(GoogleBaseHook):
         response = request(method=method, url=url, headers=headers, body=payload)
         return response
 
+    @staticmethod
+    def _check_response_status_and_data(response, message: str) -> None:
+        if response.status != 200:
+            raise AirflowException(message)
+        if response.data is None:
+            raise AirflowException(
+                "Empty response received. Please, check for possible root "
+                "causes of this behavior either in DAG code or on Cloud Datafusion side"
+            )
+
     def get_conn(self) -> Resource:
         """Retrieves connection to DataFusion."""
         if not self._conn:
@@ -206,7 +217,7 @@ class DataFusionHook(GoogleBaseHook):
     def create_instance(
         self,
         instance_name: str,
-        instance: Dict[str, Any],
+        instance: dict[str, Any],
         location: str,
         project_id: str = PROVIDE_PROJECT_ID,
     ) -> Operation:
@@ -234,7 +245,7 @@ class DataFusionHook(GoogleBaseHook):
         return operation
 
     @GoogleBaseHook.fallback_to_default_project_id
-    def get_instance(self, instance_name: str, location: str, project_id: str) -> Dict[str, Any]:
+    def get_instance(self, instance_name: str, location: str, project_id: str) -> dict[str, Any]:
         """
         Gets details of a single Data Fusion instance.
 
@@ -256,7 +267,7 @@ class DataFusionHook(GoogleBaseHook):
     def patch_instance(
         self,
         instance_name: str,
-        instance: Dict[str, Any],
+        instance: dict[str, Any],
         update_mask: str,
         location: str,
         project_id: str = PROVIDE_PROJECT_ID,
@@ -293,7 +304,7 @@ class DataFusionHook(GoogleBaseHook):
     def create_pipeline(
         self,
         pipeline_name: str,
-        pipeline: Dict[str, Any],
+        pipeline: dict[str, Any],
         instance_url: str,
         namespace: str = "default",
     ) -> None:
@@ -310,16 +321,15 @@ class DataFusionHook(GoogleBaseHook):
         """
         url = os.path.join(self._base_url(instance_url, namespace), quote(pipeline_name))
         response = self._cdap_request(url=url, method="PUT", body=pipeline)
-        if response.status != 200:
-            raise AirflowException(
-                f"Creating a pipeline failed with code {response.status} while calling {url}"
-            )
+        self._check_response_status_and_data(
+            response, f"Creating a pipeline failed with code {response.status} while calling {url}"
+        )
 
     def delete_pipeline(
         self,
         pipeline_name: str,
         instance_url: str,
-        version_id: Optional[str] = None,
+        version_id: str | None = None,
         namespace: str = "default",
     ) -> None:
         """
@@ -337,14 +347,15 @@ class DataFusionHook(GoogleBaseHook):
             url = os.path.join(url, "versions", version_id)
 
         response = self._cdap_request(url=url, method="DELETE", body=None)
-        if response.status != 200:
-            raise AirflowException(f"Deleting a pipeline failed with code {response.status}")
+        self._check_response_status_and_data(
+            response, f"Deleting a pipeline failed with code {response.status}"
+        )
 
     def list_pipelines(
         self,
         instance_url: str,
-        artifact_name: Optional[str] = None,
-        artifact_version: Optional[str] = None,
+        artifact_name: str | None = None,
+        artifact_version: str | None = None,
         namespace: str = "default",
     ) -> dict:
         """
@@ -358,7 +369,7 @@ class DataFusionHook(GoogleBaseHook):
             can create a namespace.
         """
         url = self._base_url(instance_url, namespace)
-        query: Dict[str, str] = {}
+        query: dict[str, str] = {}
         if artifact_name:
             query = {"artifactName": artifact_name}
         if artifact_version:
@@ -367,8 +378,9 @@ class DataFusionHook(GoogleBaseHook):
             url = os.path.join(url, urlencode(query))
 
         response = self._cdap_request(url=url, method="GET", body=None)
-        if response.status != 200:
-            raise AirflowException(f"Listing pipelines failed with code {response.status}")
+        self._check_response_status_and_data(
+            response, f"Listing pipelines failed with code {response.status}"
+        )
         return json.loads(response.data)
 
     def get_pipeline_workflow(
@@ -387,8 +399,9 @@ class DataFusionHook(GoogleBaseHook):
             quote(pipeline_id),
         )
         response = self._cdap_request(url=url, method="GET")
-        if response.status != 200:
-            raise AirflowException(f"Retrieving a pipeline state failed with code {response.status}")
+        self._check_response_status_and_data(
+            response, f"Retrieving a pipeline state failed with code {response.status}"
+        )
         workflow = json.loads(response.data)
         return workflow
 
@@ -397,7 +410,7 @@ class DataFusionHook(GoogleBaseHook):
         pipeline_name: str,
         instance_url: str,
         namespace: str = "default",
-        runtime_args: Optional[Dict[str, Any]] = None,
+        runtime_args: dict[str, Any] | None = None,
     ) -> str:
         """
         Starts a Cloud Data Fusion pipeline. Works for both batch and stream pipelines.
@@ -429,9 +442,9 @@ class DataFusionHook(GoogleBaseHook):
             }
         ]
         response = self._cdap_request(url=url, method="POST", body=body)
-        if response.status != 200:
-            raise AirflowException(f"Starting a pipeline failed with code {response.status}")
-
+        self._check_response_status_and_data(
+            response, f"Starting a pipeline failed with code {response.status}"
+        )
         response_json = json.loads(response.data)
         return response_json[0]["runId"]
 
@@ -453,5 +466,6 @@ class DataFusionHook(GoogleBaseHook):
             "stop",
         )
         response = self._cdap_request(url=url, method="POST")
-        if response.status != 200:
-            raise AirflowException(f"Stopping a pipeline failed with code {response.status}")
+        self._check_response_status_and_data(
+            response, f"Stopping a pipeline failed with code {response.status}"
+        )
