@@ -16,9 +16,10 @@
 # specific language governing permissions and limitations
 # under the License.
 """Hook for Google Cloud Life Sciences service"""
+from __future__ import annotations
 
 import time
-from typing import Any, Optional, Sequence, Union
+from typing import Sequence
 
 import google.api_core.path_template
 from googleapiclient.discovery import build
@@ -52,14 +53,14 @@ class LifeSciencesHook(GoogleBaseHook):
         account from the list granting this role to the originating account.
     """
 
-    _conn = None  # type: Optional[Any]
+    _conn = None
 
     def __init__(
         self,
         api_version: str = "v2beta",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
@@ -88,7 +89,6 @@ class LifeSciencesHook(GoogleBaseHook):
         :param location: The location of the project. For example: "us-east1".
         :param project_id: Optional, Google Cloud Project project_id where the function belongs.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
-        :rtype: dict
         """
         parent = self._location_path(project_id=project_id, location=location)
         service = self.get_conn()
@@ -98,7 +98,7 @@ class LifeSciencesHook(GoogleBaseHook):
         response = request.execute(num_retries=self.num_retries)
 
         # wait
-        operation_name = response['name']
+        operation_name = response["name"]
         self._wait_for_operation_to_complete(operation_name)
 
         return response
@@ -114,7 +114,7 @@ class LifeSciencesHook(GoogleBaseHook):
         :param location: The location of the project. For example: "us-east1".
         """
         return google.api_core.path_template.expand(
-            'projects/{project}/locations/{location}',
+            "projects/{project}/locations/{location}",
             project=project_id,
             location=location,
         )
@@ -126,7 +126,6 @@ class LifeSciencesHook(GoogleBaseHook):
 
         :param operation_name: The name of the operation.
         :return: The response returned by the operation.
-        :rtype: dict
         :exception: AirflowException in case error is returned.
         """
         service = self.get_conn()
@@ -138,7 +137,7 @@ class LifeSciencesHook(GoogleBaseHook):
                 .get(name=operation_name)
                 .execute(num_retries=self.num_retries)
             )
-            self.log.info('Waiting for pipeline operation to complete')
+            self.log.info("Waiting for pipeline operation to complete")
             if operation_response.get("done"):
                 response = operation_response.get("response")
                 error = operation_response.get("error")
