@@ -16,23 +16,28 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google ML Engine Hook."""
+from __future__ import annotations
+
 import logging
 import random
 import time
-from typing import Callable, Dict, List, Optional
+from typing import Callable
 
 from googleapiclient.discovery import Resource, build
 from googleapiclient.errors import HttpError
+from httplib2 import Response
 
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 from airflow.version import version as airflow_version
 
 log = logging.getLogger(__name__)
 
-_AIRFLOW_VERSION = 'v' + airflow_version.replace('.', '-').replace('+', '-')
+_AIRFLOW_VERSION = "v" + airflow_version.replace(".", "-").replace("+", "-")
 
 
-def _poll_with_exponential_delay(request, execute_num_retries, max_n, is_done_func, is_error_func):
+def _poll_with_exponential_delay(
+    request, execute_num_retries, max_n, is_done_func, is_error_func
+) -> Response:
     """
     Execute request with exponential delay.
 
@@ -46,26 +51,25 @@ def _poll_with_exponential_delay(request, execute_num_retries, max_n, is_done_fu
     :param is_done_func: callable to determine if operation is done.
     :param is_error_func: callable to determine if operation is failed.
     :return: response
-    :rtype: httplib2.Response
     """
     for i in range(0, max_n):
         try:
             response = request.execute(num_retries=execute_num_retries)
             if is_error_func(response):
-                raise ValueError(f'The response contained an error: {response}')
+                raise ValueError(f"The response contained an error: {response}")
             if is_done_func(response):
-                log.info('Operation is done: %s', response)
+                log.info("Operation is done: %s", response)
                 return response
 
             time.sleep((2**i) + (random.randint(0, 1000) / 1000))
         except HttpError as e:
             if e.resp.status != 429:
-                log.info('Something went wrong. Not retrying: %s', format(e))
+                log.info("Something went wrong. Not retrying: %s", format(e))
                 raise
             else:
                 time.sleep((2**i) + (random.randint(0, 1000) / 1000))
 
-    raise ValueError(f'Connection could not be established after {max_n} retries.')
+    raise ValueError(f"Connection could not be established after {max_n} retries.")
 
 
 class MLEngineHook(GoogleBaseHook):
@@ -83,10 +87,10 @@ class MLEngineHook(GoogleBaseHook):
         :return: Google MLEngine services object.
         """
         authed_http = self._authorize()
-        return build('ml', 'v1', http=authed_http, cache_discovery=False)
+        return build("ml", "v1", http=authed_http, cache_discovery=False)
 
     @GoogleBaseHook.fallback_to_default_project_id
-    def create_job(self, job: dict, project_id: str, use_existing_job_fn: Optional[Callable] = None) -> dict:
+    def create_job(self, job: dict, project_id: str, use_existing_job_fn: Callable | None = None) -> dict:
         """
         Launches a MLEngine job and wait for it to reach a terminal state.
 
@@ -113,15 +117,14 @@ class MLEngineHook(GoogleBaseHook):
             we by default reuse the existing MLEngine job.
         :return: The MLEngine job object if the job successfully reach a
             terminal state (which might be FAILED or CANCELLED state).
-        :rtype: dict
         """
         hook = self.get_conn()
 
         self._append_label(job)
         self.log.info("Creating job.")
 
-        request = hook.projects().jobs().create(parent=f'projects/{project_id}', body=job)
-        job_id = job['jobId']
+        request = hook.projects().jobs().create(parent=f"projects/{project_id}", body=job)
+        job_id = job["jobId"]
 
         try:
             request.execute(num_retries=self.num_retries)
@@ -132,14 +135,14 @@ class MLEngineHook(GoogleBaseHook):
                     existing_job = self._get_job(project_id, job_id)
                     if not use_existing_job_fn(existing_job):
                         self.log.error(
-                            'Job with job_id %s already exist, but it does not match our expectation: %s',
+                            "Job with job_id %s already exist, but it does not match our expectation: %s",
                             job_id,
                             existing_job,
                         )
                         raise
-                self.log.info('Job with job_id %s already exist. Will waiting for it to finish', job_id)
+                self.log.info("Job with job_id %s already exist. Will waiting for it to finish", job_id)
             else:
-                self.log.error('Failed to create MLEngine job: %s', e)
+                self.log.error("Failed to create MLEngine job: %s", e)
                 raise
 
         return self._wait_for_job_done(project_id, job_id)
@@ -159,24 +162,23 @@ class MLEngineHook(GoogleBaseHook):
         :param job_id: A unique id for the want-to-be cancelled Google MLEngine training job.
 
         :return: Empty dict if cancelled successfully
-        :rtype: dict
         :raises: googleapiclient.errors.HttpError
         """
         hook = self.get_conn()
 
-        request = hook.projects().jobs().cancel(name=f'projects/{project_id}/jobs/{job_id}')
+        request = hook.projects().jobs().cancel(name=f"projects/{project_id}/jobs/{job_id}")
 
         try:
             return request.execute(num_retries=self.num_retries)
         except HttpError as e:
             if e.resp.status == 404:
-                self.log.error('Job with job_id %s does not exist. ', job_id)
+                self.log.error("Job with job_id %s does not exist. ", job_id)
                 raise
             elif e.resp.status == 400:
-                self.log.info('Job with job_id %s is already complete, cancellation aborted.', job_id)
+                self.log.info("Job with job_id %s is already complete, cancellation aborted.", job_id)
                 return {}
             else:
-                self.log.error('Failed to cancel MLEngine job: %s', e)
+                self.log.error("Failed to cancel MLEngine job: %s", e)
                 raise
 
     def _get_job(self, project_id: str, job_id: str) -> dict:
@@ -187,11 +189,10 @@ class MLEngineHook(GoogleBaseHook):
             project_id from the Google Cloud connection is used. (templated)
         :param job_id: A unique id for the Google MLEngine job. (templated)
         :return: MLEngine job object if succeed.
-        :rtype: dict
         :raises: googleapiclient.errors.HttpError
         """
         hook = self.get_conn()
-        job_name = f'projects/{project_id}/jobs/{job_id}'
+        job_name = f"projects/{project_id}/jobs/{job_id}"
         request = hook.projects().jobs().get(name=job_name)
         while True:
             try:
@@ -201,7 +202,7 @@ class MLEngineHook(GoogleBaseHook):
                     # polling after 30 seconds when quota failure occurs
                     time.sleep(30)
                 else:
-                    self.log.error('Failed to get MLEngine job: %s', e)
+                    self.log.error("Failed to get MLEngine job: %s", e)
                     raise
 
     def _wait_for_job_done(self, project_id: str, job_id: str, interval: int = 30):
@@ -223,7 +224,7 @@ class MLEngineHook(GoogleBaseHook):
             raise ValueError("Interval must be > 0")
         while True:
             job = self._get_job(project_id, job_id)
-            if job['state'] in ['SUCCEEDED', 'FAILED', 'CANCELLED']:
+            if job["state"] in ["SUCCEEDED", "FAILED", "CANCELLED"]:
                 return job
             time.sleep(interval)
 
@@ -231,7 +232,7 @@ class MLEngineHook(GoogleBaseHook):
     def create_version(
         self,
         model_name: str,
-        version_spec: Dict,
+        version_spec: dict,
         project_id: str,
     ) -> dict:
         """
@@ -245,23 +246,22 @@ class MLEngineHook(GoogleBaseHook):
             (templated)
         :return: If the version was created successfully, returns the operation.
             Otherwise raises an error .
-        :rtype: dict
         """
         hook = self.get_conn()
-        parent_name = f'projects/{project_id}/models/{model_name}'
+        parent_name = f"projects/{project_id}/models/{model_name}"
 
         self._append_label(version_spec)
 
         create_request = hook.projects().models().versions().create(parent=parent_name, body=version_spec)
         response = create_request.execute(num_retries=self.num_retries)
-        get_request = hook.projects().operations().get(name=response['name'])
+        get_request = hook.projects().operations().get(name=response["name"])
 
         return _poll_with_exponential_delay(
             request=get_request,
             execute_num_retries=self.num_retries,
             max_n=9,
-            is_done_func=lambda resp: resp.get('done', False),
-            is_error_func=lambda resp: resp.get('error', None) is not None,
+            is_done_func=lambda resp: resp.get("done", False),
+            is_error_func=lambda resp: resp.get("error", None) is not None,
         )
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -281,20 +281,19 @@ class MLEngineHook(GoogleBaseHook):
             or missing, the default project_id from the Google Cloud connection is used. (templated)
         :return: If successful, return an instance of Version.
             Otherwise raises an error.
-        :rtype: dict
         :raises: googleapiclient.errors.HttpError
         """
         hook = self.get_conn()
-        full_version_name = f'projects/{project_id}/models/{model_name}/versions/{version_name}'
+        full_version_name = f"projects/{project_id}/models/{model_name}/versions/{version_name}"
 
         request = hook.projects().models().versions().setDefault(name=full_version_name, body={})
 
         try:
             response = request.execute(num_retries=self.num_retries)
-            self.log.info('Successfully set version: %s to default', response)
+            self.log.info("Successfully set version: %s to default", response)
             return response
         except HttpError as e:
-            self.log.error('Something went wrong: %s', e)
+            self.log.error("Something went wrong: %s", e)
             raise
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -302,7 +301,7 @@ class MLEngineHook(GoogleBaseHook):
         self,
         model_name: str,
         project_id: str,
-    ) -> List[dict]:
+    ) -> list[dict]:
         """
         Lists all available versions of a model. Blocks until finished.
 
@@ -311,18 +310,17 @@ class MLEngineHook(GoogleBaseHook):
         :param project_id: The Google Cloud project name to which MLEngine model belongs. If set to None or
             missing, the default project_id from the Google Cloud connection is used. (templated)
         :return: return an list of instance of Version.
-        :rtype: List[Dict]
         :raises: googleapiclient.errors.HttpError
         """
         hook = self.get_conn()
-        result = []  # type: List[Dict]
-        full_parent_name = f'projects/{project_id}/models/{model_name}'
+        result: list[dict] = []
+        full_parent_name = f"projects/{project_id}/models/{model_name}"
 
         request = hook.projects().models().versions().list(parent=full_parent_name, pageSize=100)
 
         while request is not None:
             response = request.execute(num_retries=self.num_retries)
-            result.extend(response.get('versions', []))
+            result.extend(response.get("versions", []))
 
             request = (
                 hook.projects()
@@ -349,20 +347,19 @@ class MLEngineHook(GoogleBaseHook):
             model belongs.
         :return: If the version was deleted successfully, returns the operation.
             Otherwise raises an error.
-        :rtype: Dict
         """
         hook = self.get_conn()
-        full_name = f'projects/{project_id}/models/{model_name}/versions/{version_name}'
+        full_name = f"projects/{project_id}/models/{model_name}/versions/{version_name}"
         delete_request = hook.projects().models().versions().delete(name=full_name)
         response = delete_request.execute(num_retries=self.num_retries)
-        get_request = hook.projects().operations().get(name=response['name'])
+        get_request = hook.projects().operations().get(name=response["name"])
 
         return _poll_with_exponential_delay(
             request=get_request,
             execute_num_retries=self.num_retries,
             max_n=9,
-            is_done_func=lambda resp: resp.get('done', False),
-            is_error_func=lambda resp: resp.get('error', None) is not None,
+            is_done_func=lambda resp: resp.get("done", False),
+            is_error_func=lambda resp: resp.get("error", None) is not None,
         )
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -379,13 +376,12 @@ class MLEngineHook(GoogleBaseHook):
             missing, the default project_id from the Google Cloud connection is used. (templated)
         :return: If the version was created successfully, returns the instance of Model.
             Otherwise raises an error.
-        :rtype: Dict
         :raises: googleapiclient.errors.HttpError
         """
         hook = self.get_conn()
-        if 'name' not in model or not model['name']:
+        if "name" not in model or not model["name"]:
             raise ValueError("Model name must be provided and could not be an empty string")
-        project = f'projects/{project_id}'
+        project = f"projects/{project_id}"
 
         self._append_label(model)
         try:
@@ -399,19 +395,19 @@ class MLEngineHook(GoogleBaseHook):
                 raise e
 
             error_detail = e.error_details[0]
-            if error_detail["@type"] != 'type.googleapis.com/google.rpc.BadRequest':
+            if error_detail["@type"] != "type.googleapis.com/google.rpc.BadRequest":
                 raise e
 
-            if "fieldViolations" not in error_detail or len(error_detail['fieldViolations']) != 1:
+            if "fieldViolations" not in error_detail or len(error_detail["fieldViolations"]) != 1:
                 raise e
 
-            field_violation = error_detail['fieldViolations'][0]
+            field_violation = error_detail["fieldViolations"][0]
             if (
                 field_violation["field"] != "model.name"
                 or field_violation["description"] != "A model with the same name already exists."
             ):
                 raise e
-            response = self.get_model(model_name=model['name'], project_id=project_id)
+            response = self.get_model(model_name=model["name"], project_id=project_id)
 
         return response
 
@@ -420,7 +416,7 @@ class MLEngineHook(GoogleBaseHook):
         self,
         model_name: str,
         project_id: str,
-    ) -> Optional[dict]:
+    ) -> dict | None:
         """
         Gets a Model. Blocks until finished.
 
@@ -429,19 +425,18 @@ class MLEngineHook(GoogleBaseHook):
             or missing, the default project_id from the Google Cloud connection is used. (templated)
         :return: If the model exists, returns the instance of Model.
             Otherwise return None.
-        :rtype: Dict
         :raises: googleapiclient.errors.HttpError
         """
         hook = self.get_conn()
         if not model_name:
             raise ValueError("Model name must be provided and it could not be an empty string")
-        full_model_name = f'projects/{project_id}/models/{model_name}'
+        full_model_name = f"projects/{project_id}/models/{model_name}"
         request = hook.projects().models().get(name=full_model_name)
         try:
             return request.execute(num_retries=self.num_retries)
         except HttpError as e:
             if e.resp.status == 404:
-                self.log.error('Model was not found: %s', e)
+                self.log.error("Model was not found: %s", e)
                 return None
             raise
 
@@ -467,7 +462,7 @@ class MLEngineHook(GoogleBaseHook):
 
         if not model_name:
             raise ValueError("Model name must be provided and it could not be an empty string")
-        model_path = f'projects/{project_id}/models/{model_name}'
+        model_path = f"projects/{project_id}/models/{model_name}"
         if delete_contents:
             self._delete_all_versions(model_name, project_id)
         request = hook.projects().models().delete(name=model_path)
@@ -475,22 +470,22 @@ class MLEngineHook(GoogleBaseHook):
             request.execute(num_retries=self.num_retries)
         except HttpError as e:
             if e.resp.status == 404:
-                self.log.error('Model was not found: %s', e)
+                self.log.error("Model was not found: %s", e)
                 return
             raise
 
     def _delete_all_versions(self, model_name: str, project_id: str):
         versions = self.list_versions(project_id=project_id, model_name=model_name)
         # The default version can only be deleted when it is the last one in the model
-        non_default_versions = (version for version in versions if not version.get('isDefault', False))
+        non_default_versions = (version for version in versions if not version.get("isDefault", False))
         for version in non_default_versions:
-            _, _, version_name = version['name'].rpartition('/')
+            _, _, version_name = version["name"].rpartition("/")
             self.delete_version(project_id=project_id, model_name=model_name, version_name=version_name)
-        default_versions = (version for version in versions if version.get('isDefault', False))
+        default_versions = (version for version in versions if version.get("isDefault", False))
         for version in default_versions:
-            _, _, version_name = version['name'].rpartition('/')
+            _, _, version_name = version["name"].rpartition("/")
             self.delete_version(project_id=project_id, model_name=model_name, version_name=version_name)
 
     def _append_label(self, model: dict) -> None:
-        model['labels'] = model.get('labels', {})
-        model['labels']['airflow-version'] = _AIRFLOW_VERSION
+        model["labels"] = model.get("labels", {})
+        model["labels"]["airflow-version"] = _AIRFLOW_VERSION
