@@ -16,8 +16,10 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Vision Hook."""
+from __future__ import annotations
+
 from copy import deepcopy
-from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
@@ -58,7 +60,7 @@ class NameDeterminer:
         self.get_path = get_path
 
     def get_entity_with_name(
-        self, entity: Any, entity_id: Optional[str], location: Optional[str], project_id: str
+        self, entity: Any, entity_id: str | None, location: str | None, project_id: str
     ) -> Any:
         """
         Check if entity has the `name` attribute set:
@@ -80,11 +82,10 @@ class NameDeterminer:
         :param location: Location
         :param project_id: The id of Google Cloud Vision project.
         :return: The same entity or entity with new name
-        :rtype: str
         :raises: AirflowException
         """
         entity = deepcopy(entity)
-        explicit_name = getattr(entity, 'name')
+        explicit_name = getattr(entity, "name")
         if location and entity_id:
             # Necessary parameters to construct the name are present. Checking for conflict with explicit name
             constructed_name = self.get_path(project_id, location, entity_id)
@@ -117,16 +118,16 @@ class CloudVisionHook(GoogleBaseHook):
     keyword arguments rather than positional.
     """
 
-    product_name_determiner = NameDeterminer('Product', 'product_id', ProductSearchClient.product_path)
+    product_name_determiner = NameDeterminer("Product", "product_id", ProductSearchClient.product_path)
     product_set_name_determiner = NameDeterminer(
-        'ProductSet', 'productset_id', ProductSearchClient.product_set_path
+        "ProductSet", "productset_id", ProductSearchClient.product_set_path
     )
 
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
@@ -140,7 +141,6 @@ class CloudVisionHook(GoogleBaseHook):
         Retrieves connection to Cloud Vision.
 
         :return: Google Cloud Vision client object.
-        :rtype: google.cloud.vision_v1.ProductSearchClient
         """
         if not self._client:
             self._client = ProductSearchClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
@@ -152,12 +152,11 @@ class CloudVisionHook(GoogleBaseHook):
         Creates ImageAnnotatorClient.
 
         :return: Google Image Annotator client object.
-        :rtype: google.cloud.vision_v1.ImageAnnotatorClient
         """
         return ImageAnnotatorClient(credentials=self.get_credentials())
 
     @staticmethod
-    def _check_for_error(response: Dict) -> None:
+    def _check_for_error(response: dict) -> None:
         if "error" in response:
             raise AirflowException(response)
 
@@ -165,12 +164,12 @@ class CloudVisionHook(GoogleBaseHook):
     def create_product_set(
         self,
         location: str,
-        product_set: Union[dict, ProductSet],
+        product_set: dict | ProductSet,
         project_id: str = PROVIDE_PROJECT_ID,
-        product_set_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        product_set_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> str:
         """
         For the documentation see:
@@ -178,7 +177,7 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.get_conn()
         parent = ProductSearchClient.location_path(project_id, location)
-        self.log.info('Creating a new ProductSet under the parent: %s', parent)
+        self.log.info("Creating a new ProductSet under the parent: %s", parent)
         response = client.create_product_set(
             parent=parent,
             product_set=product_set,
@@ -187,13 +186,13 @@ class CloudVisionHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
-        self.log.info('ProductSet created: %s', response.name if response else '')
-        self.log.debug('ProductSet created:\n%s', response)
+        self.log.info("ProductSet created: %s", response.name if response else "")
+        self.log.debug("ProductSet created:\n%s", response)
 
         if not product_set_id:
             # Product set id was generated by the API
             product_set_id = self._get_autogenerated_id(response)
-            self.log.info('Extracted autogenerated ProductSet ID from the response: %s', product_set_id)
+            self.log.info("Extracted autogenerated ProductSet ID from the response: %s", product_set_id)
 
         return product_set_id
 
@@ -203,9 +202,9 @@ class CloudVisionHook(GoogleBaseHook):
         location: str,
         product_set_id: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> dict:
         """
         For the documentation see:
@@ -213,23 +212,23 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.get_conn()
         name = ProductSearchClient.product_set_path(project_id, location, product_set_id)
-        self.log.info('Retrieving ProductSet: %s', name)
+        self.log.info("Retrieving ProductSet: %s", name)
         response = client.get_product_set(name=name, retry=retry, timeout=timeout, metadata=metadata)
-        self.log.info('ProductSet retrieved.')
-        self.log.debug('ProductSet retrieved:\n%s', response)
+        self.log.info("ProductSet retrieved.")
+        self.log.debug("ProductSet retrieved:\n%s", response)
         return MessageToDict(response)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def update_product_set(
         self,
-        product_set: Union[dict, ProductSet],
+        product_set: dict | ProductSet,
         project_id: str = PROVIDE_PROJECT_ID,
-        location: Optional[str] = None,
-        product_set_id: Optional[str] = None,
-        update_mask: Union[dict, FieldMask] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        location: str | None = None,
+        product_set_id: str | None = None,
+        update_mask: dict | FieldMask = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> dict:
         """
         For the documentation see:
@@ -239,12 +238,12 @@ class CloudVisionHook(GoogleBaseHook):
         product_set = self.product_set_name_determiner.get_entity_with_name(
             product_set, product_set_id, location, project_id
         )
-        self.log.info('Updating ProductSet: %s', product_set.name)
+        self.log.info("Updating ProductSet: %s", product_set.name)
         response = client.update_product_set(
             product_set=product_set, update_mask=update_mask, retry=retry, timeout=timeout, metadata=metadata
         )
-        self.log.info('ProductSet updated: %s', response.name if response else '')
-        self.log.debug('ProductSet updated:\n%s', response)
+        self.log.info("ProductSet updated: %s", response.name if response else "")
+        self.log.debug("ProductSet updated:\n%s", response)
         return MessageToDict(response)
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -253,9 +252,9 @@ class CloudVisionHook(GoogleBaseHook):
         location: str,
         product_set_id: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
         For the documentation see:
@@ -263,20 +262,20 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.get_conn()
         name = ProductSearchClient.product_set_path(project_id, location, product_set_id)
-        self.log.info('Deleting ProductSet: %s', name)
+        self.log.info("Deleting ProductSet: %s", name)
         client.delete_product_set(name=name, retry=retry, timeout=timeout, metadata=metadata)
-        self.log.info('ProductSet with the name [%s] deleted.', name)
+        self.log.info("ProductSet with the name [%s] deleted.", name)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def create_product(
         self,
         location: str,
-        product: Union[dict, Product],
+        product: dict | Product,
         project_id: str = PROVIDE_PROJECT_ID,
-        product_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        product_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         For the documentation see:
@@ -284,7 +283,7 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.get_conn()
         parent = ProductSearchClient.location_path(project_id, location)
-        self.log.info('Creating a new Product under the parent: %s', parent)
+        self.log.info("Creating a new Product under the parent: %s", parent)
         response = client.create_product(
             parent=parent,
             product=product,
@@ -293,13 +292,13 @@ class CloudVisionHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
-        self.log.info('Product created: %s', response.name if response else '')
-        self.log.debug('Product created:\n%s', response)
+        self.log.info("Product created: %s", response.name if response else "")
+        self.log.debug("Product created:\n%s", response)
 
         if not product_id:
             # Product id was generated by the API
             product_id = self._get_autogenerated_id(response)
-            self.log.info('Extracted autogenerated Product ID from the response: %s', product_id)
+            self.log.info("Extracted autogenerated Product ID from the response: %s", product_id)
 
         return product_id
 
@@ -309,9 +308,9 @@ class CloudVisionHook(GoogleBaseHook):
         location: str,
         product_id: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         For the documentation see:
@@ -319,23 +318,23 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.get_conn()
         name = ProductSearchClient.product_path(project_id, location, product_id)
-        self.log.info('Retrieving Product: %s', name)
+        self.log.info("Retrieving Product: %s", name)
         response = client.get_product(name=name, retry=retry, timeout=timeout, metadata=metadata)
-        self.log.info('Product retrieved.')
-        self.log.debug('Product retrieved:\n%s', response)
+        self.log.info("Product retrieved.")
+        self.log.debug("Product retrieved:\n%s", response)
         return MessageToDict(response)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def update_product(
         self,
-        product: Union[dict, Product],
+        product: dict | Product,
         project_id: str = PROVIDE_PROJECT_ID,
-        location: Optional[str] = None,
-        product_id: Optional[str] = None,
-        update_mask: Optional[Dict[str, FieldMask]] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        location: str | None = None,
+        product_id: str | None = None,
+        update_mask: dict[str, FieldMask] | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         For the documentation see:
@@ -343,12 +342,12 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.get_conn()
         product = self.product_name_determiner.get_entity_with_name(product, product_id, location, project_id)
-        self.log.info('Updating ProductSet: %s', product.name)
+        self.log.info("Updating ProductSet: %s", product.name)
         response = client.update_product(
             product=product, update_mask=update_mask, retry=retry, timeout=timeout, metadata=metadata
         )
-        self.log.info('Product updated: %s', response.name if response else '')
-        self.log.debug('Product updated:\n%s', response)
+        self.log.info("Product updated: %s", response.name if response else "")
+        self.log.debug("Product updated:\n%s", response)
         return MessageToDict(response)
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -357,9 +356,9 @@ class CloudVisionHook(GoogleBaseHook):
         location: str,
         product_id: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
         For the documentation see:
@@ -367,28 +366,28 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.get_conn()
         name = ProductSearchClient.product_path(project_id, location, product_id)
-        self.log.info('Deleting ProductSet: %s', name)
+        self.log.info("Deleting ProductSet: %s", name)
         client.delete_product(name=name, retry=retry, timeout=timeout, metadata=metadata)
-        self.log.info('Product with the name [%s] deleted:', name)
+        self.log.info("Product with the name [%s] deleted:", name)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def create_reference_image(
         self,
         location: str,
         product_id: str,
-        reference_image: Union[dict, ReferenceImage],
+        reference_image: dict | ReferenceImage,
         project_id: str,
-        reference_image_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        reference_image_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> str:
         """
         For the documentation see:
         :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionCreateReferenceImageOperator`
         """
         client = self.get_conn()
-        self.log.info('Creating ReferenceImage')
+        self.log.info("Creating ReferenceImage")
         parent = ProductSearchClient.product_path(project=project_id, location=location, product=product_id)
 
         response = client.create_reference_image(
@@ -400,14 +399,14 @@ class CloudVisionHook(GoogleBaseHook):
             metadata=metadata,
         )
 
-        self.log.info('ReferenceImage created: %s', response.name if response else '')
-        self.log.debug('ReferenceImage created:\n%s', response)
+        self.log.info("ReferenceImage created: %s", response.name if response else "")
+        self.log.debug("ReferenceImage created:\n%s", response)
 
         if not reference_image_id:
             # Reference image  id was generated by the API
             reference_image_id = self._get_autogenerated_id(response)
             self.log.info(
-                'Extracted autogenerated ReferenceImage ID from the response: %s', reference_image_id
+                "Extracted autogenerated ReferenceImage ID from the response: %s", reference_image_id
             )
 
         return reference_image_id
@@ -419,29 +418,28 @@ class CloudVisionHook(GoogleBaseHook):
         product_id: str,
         reference_image_id: str,
         project_id: str,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
-    ) -> dict:
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
+    ) -> None:
         """
         For the documentation see:
         :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionDeleteReferenceImageOperator`
         """
         client = self.get_conn()
-        self.log.info('Deleting ReferenceImage')
+        self.log.info("Deleting ReferenceImage")
         name = ProductSearchClient.reference_image_path(
             project=project_id, location=location, product=product_id, reference_image=reference_image_id
         )
 
-        response = client.delete_reference_image(
+        client.delete_reference_image(
             name=name,
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
 
-        self.log.info('ReferenceImage with the name [%s] deleted.', name)
-        return MessageToDict(response)
+        self.log.info("ReferenceImage with the name [%s] deleted.", name)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def add_product_to_product_set(
@@ -449,10 +447,10 @@ class CloudVisionHook(GoogleBaseHook):
         product_set_id: str,
         product_id: str,
         project_id: str,
-        location: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        location: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
         For the documentation see:
@@ -463,13 +461,13 @@ class CloudVisionHook(GoogleBaseHook):
         product_name = ProductSearchClient.product_path(project_id, location, product_id)
         product_set_name = ProductSearchClient.product_set_path(project_id, location, product_set_id)
 
-        self.log.info('Add Product[name=%s] to Product Set[name=%s]', product_name, product_set_name)
+        self.log.info("Add Product[name=%s] to Product Set[name=%s]", product_name, product_set_name)
 
         client.add_product_to_product_set(
             name=product_set_name, product=product_name, retry=retry, timeout=timeout, metadata=metadata
         )
 
-        self.log.info('Product added to Product Set')
+        self.log.info("Product added to Product Set")
 
     @GoogleBaseHook.fallback_to_default_project_id
     def remove_product_from_product_set(
@@ -477,10 +475,10 @@ class CloudVisionHook(GoogleBaseHook):
         product_set_id: str,
         product_id: str,
         project_id: str,
-        location: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        location: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
         For the documentation see:
@@ -491,40 +489,19 @@ class CloudVisionHook(GoogleBaseHook):
         product_name = ProductSearchClient.product_path(project_id, location, product_id)
         product_set_name = ProductSearchClient.product_set_path(project_id, location, product_set_id)
 
-        self.log.info('Remove Product[name=%s] from Product Set[name=%s]', product_name, product_set_name)
+        self.log.info("Remove Product[name=%s] from Product Set[name=%s]", product_name, product_set_name)
 
         client.remove_product_from_product_set(
             name=product_set_name, product=product_name, retry=retry, timeout=timeout, metadata=metadata
         )
 
-        self.log.info('Product removed from Product Set')
+        self.log.info("Product removed from Product Set")
 
     def annotate_image(
         self,
-        request: Union[dict, AnnotateImageRequest],
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-    ) -> Dict:
-        """
-        For the documentation see:
-        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionImageAnnotateOperator`
-        """
-        client = self.annotator_client
-
-        self.log.info('Annotating image')
-
-        response = client.annotate_image(request=request, retry=retry, timeout=timeout)
-
-        self.log.info('Image annotated')
-
-        return MessageToDict(response)
-
-    @GoogleBaseHook.quota_retry()
-    def batch_annotate_images(
-        self,
-        requests: Union[List[dict], List[AnnotateImageRequest]],
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
+        request: dict | AnnotateImageRequest,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
     ) -> dict:
         """
         For the documentation see:
@@ -532,22 +509,43 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.annotator_client
 
-        self.log.info('Annotating images')
+        self.log.info("Annotating image")
+
+        response = client.annotate_image(request=request, retry=retry, timeout=timeout)
+
+        self.log.info("Image annotated")
+
+        return MessageToDict(response)
+
+    @GoogleBaseHook.quota_retry()
+    def batch_annotate_images(
+        self,
+        requests: list[dict] | list[AnnotateImageRequest],
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+    ) -> dict:
+        """
+        For the documentation see:
+        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionImageAnnotateOperator`
+        """
+        client = self.annotator_client
+
+        self.log.info("Annotating images")
 
         response = client.batch_annotate_images(requests=requests, retry=retry, timeout=timeout)
 
-        self.log.info('Images annotated')
+        self.log.info("Images annotated")
 
         return MessageToDict(response)
 
     @GoogleBaseHook.quota_retry()
     def text_detection(
         self,
-        image: Union[dict, Image],
-        max_results: Optional[int] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        additional_properties: Optional[Dict] = None,
+        image: dict | Image,
+        max_results: int | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        additional_properties: dict | None = None,
     ) -> dict:
         """
         For the documentation see:
@@ -573,11 +571,11 @@ class CloudVisionHook(GoogleBaseHook):
     @GoogleBaseHook.quota_retry()
     def document_text_detection(
         self,
-        image: Union[dict, Image],
-        max_results: Optional[int] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        additional_properties: Optional[dict] = None,
+        image: dict | Image,
+        max_results: int | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        additional_properties: dict | None = None,
     ) -> dict:
         """
         For the documentation see:
@@ -603,11 +601,11 @@ class CloudVisionHook(GoogleBaseHook):
     @GoogleBaseHook.quota_retry()
     def label_detection(
         self,
-        image: Union[dict, Image],
-        max_results: Optional[int] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        additional_properties: Optional[dict] = None,
+        image: dict | Image,
+        max_results: int | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        additional_properties: dict | None = None,
     ) -> dict:
         """
         For the documentation see:
@@ -633,11 +631,11 @@ class CloudVisionHook(GoogleBaseHook):
     @GoogleBaseHook.quota_retry()
     def safe_search_detection(
         self,
-        image: Union[dict, Image],
-        max_results: Optional[int] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        additional_properties: Optional[dict] = None,
+        image: dict | Image,
+        max_results: int | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        additional_properties: dict | None = None,
     ) -> dict:
         """
         For the documentation see:
@@ -664,7 +662,7 @@ class CloudVisionHook(GoogleBaseHook):
         try:
             name = response.name
         except AttributeError as e:
-            raise AirflowException(f'Unable to get name from response... [{response}]\n{e}')
-        if '/' not in name:
-            raise AirflowException(f'Unable to get id from name... [{name}]')
-        return name.rsplit('/', 1)[1]
+            raise AirflowException(f"Unable to get name from response... [{response}]\n{e}")
+        if "/" not in name:
+            raise AirflowException(f"Unable to get id from name... [{name}]")
+        return name.rsplit("/", 1)[1]
