@@ -16,9 +16,10 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Vision operator."""
+from __future__ import annotations
 
 from copy import deepcopy
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence, Tuple, Union
+from typing import TYPE_CHECKING, Any, Sequence, Tuple
 
 from google.api_core.exceptions import AlreadyExists
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
@@ -90,15 +91,15 @@ class CloudVisionCreateProductSetOperator(BaseOperator):
     def __init__(
         self,
         *,
-        product_set: Union[dict, ProductSet],
+        product_set: dict | ProductSet,
         location: str,
-        project_id: Optional[str] = None,
-        product_set_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        product_set_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -112,7 +113,7 @@ class CloudVisionCreateProductSetOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -167,11 +168,11 @@ class CloudVisionGetProductSetOperator(BaseOperator):
 
     # [START vision_productset_get_template_fields]
     template_fields: Sequence[str] = (
-        'location',
-        'project_id',
-        'product_set_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "location",
+        "project_id",
+        "product_set_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_productset_get_template_fields]
 
@@ -180,12 +181,12 @@ class CloudVisionGetProductSetOperator(BaseOperator):
         *,
         location: str,
         product_set_id: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -198,7 +199,7 @@ class CloudVisionGetProductSetOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -262,27 +263,27 @@ class CloudVisionUpdateProductSetOperator(BaseOperator):
 
     # [START vision_productset_update_template_fields]
     template_fields: Sequence[str] = (
-        'location',
-        'project_id',
-        'product_set_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "location",
+        "project_id",
+        "product_set_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_productset_update_template_fields]
 
     def __init__(
         self,
         *,
-        product_set: Union[Dict, ProductSet],
-        location: Optional[str] = None,
-        product_set_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        update_mask: Union[Dict, FieldMask] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
+        product_set: dict | ProductSet,
+        location: str | None = None,
+        product_set_id: str | None = None,
+        project_id: str | None = None,
+        update_mask: dict | FieldMask = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -297,7 +298,7 @@ class CloudVisionUpdateProductSetOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -348,11 +349,11 @@ class CloudVisionDeleteProductSetOperator(BaseOperator):
 
     # [START vision_productset_delete_template_fields]
     template_fields: Sequence[str] = (
-        'location',
-        'project_id',
-        'product_set_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "location",
+        "project_id",
+        "product_set_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_productset_delete_template_fields]
 
@@ -361,12 +362,12 @@ class CloudVisionDeleteProductSetOperator(BaseOperator):
         *,
         location: str,
         product_set_id: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -379,7 +380,7 @@ class CloudVisionDeleteProductSetOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -437,11 +438,11 @@ class CloudVisionCreateProductOperator(BaseOperator):
 
     # [START vision_product_create_template_fields]
     template_fields: Sequence[str] = (
-        'location',
-        'project_id',
-        'product_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "location",
+        "project_id",
+        "product_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_product_create_template_fields]
 
@@ -450,13 +451,13 @@ class CloudVisionCreateProductOperator(BaseOperator):
         *,
         location: str,
         product: str,
-        project_id: Optional[str] = None,
-        product_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        product_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -470,7 +471,7 @@ class CloudVisionCreateProductOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -487,7 +488,7 @@ class CloudVisionCreateProductOperator(BaseOperator):
             )
         except AlreadyExists:
             self.log.info(
-                'Product with id %s already exists. Exiting from the create operation.', self.product_id
+                "Product with id %s already exists. Exiting from the create operation.", self.product_id
             )
             return self.product_id
 
@@ -528,11 +529,11 @@ class CloudVisionGetProductOperator(BaseOperator):
 
     # [START vision_product_get_template_fields]
     template_fields: Sequence[str] = (
-        'location',
-        'project_id',
-        'product_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "location",
+        "project_id",
+        "product_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_product_get_template_fields]
 
@@ -541,12 +542,12 @@ class CloudVisionGetProductOperator(BaseOperator):
         *,
         location: str,
         product_id: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -559,7 +560,7 @@ class CloudVisionGetProductOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -634,27 +635,27 @@ class CloudVisionUpdateProductOperator(BaseOperator):
 
     # [START vision_product_update_template_fields]
     template_fields: Sequence[str] = (
-        'location',
-        'project_id',
-        'product_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "location",
+        "project_id",
+        "product_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_product_update_template_fields]
 
     def __init__(
         self,
         *,
-        product: Union[Dict, Product],
-        location: Optional[str] = None,
-        product_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        update_mask: Union[Dict, FieldMask] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
+        product: dict | Product,
+        location: str | None = None,
+        product_id: str | None = None,
+        project_id: str | None = None,
+        update_mask: dict | FieldMask = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -669,7 +670,7 @@ class CloudVisionUpdateProductOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -725,11 +726,11 @@ class CloudVisionDeleteProductOperator(BaseOperator):
 
     # [START vision_product_delete_template_fields]
     template_fields: Sequence[str] = (
-        'location',
-        'project_id',
-        'product_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "location",
+        "project_id",
+        "product_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_product_delete_template_fields]
 
@@ -738,12 +739,12 @@ class CloudVisionDeleteProductOperator(BaseOperator):
         *,
         location: str,
         product_id: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -756,7 +757,7 @@ class CloudVisionDeleteProductOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -800,20 +801,20 @@ class CloudVisionImageAnnotateOperator(BaseOperator):
 
     # [START vision_annotate_image_template_fields]
     template_fields: Sequence[str] = (
-        'request',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "request",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_annotate_image_template_fields]
 
     def __init__(
         self,
         *,
-        request: Union[Dict, AnnotateImageRequest],
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        request: dict | AnnotateImageRequest,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -823,7 +824,7 @@ class CloudVisionImageAnnotateOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -893,15 +894,15 @@ class CloudVisionCreateReferenceImageOperator(BaseOperator):
         self,
         *,
         location: str,
-        reference_image: Union[Dict, ReferenceImage],
+        reference_image: dict | ReferenceImage,
         product_id: str,
-        reference_image_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
+        reference_image_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -916,7 +917,7 @@ class CloudVisionCreateReferenceImageOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         try:
             hook = CloudVisionHook(
                 gcp_conn_id=self.gcp_conn_id,
@@ -991,12 +992,12 @@ class CloudVisionDeleteReferenceImageOperator(BaseOperator):
         location: str,
         product_id: str,
         reference_image_id: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1010,7 +1011,7 @@ class CloudVisionDeleteReferenceImageOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -1080,12 +1081,12 @@ class CloudVisionAddProductToProductSetOperator(BaseOperator):
         product_set_id: str,
         product_id: str,
         location: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1099,7 +1100,7 @@ class CloudVisionAddProductToProductSetOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -1163,12 +1164,12 @@ class CloudVisionRemoveProductFromProductSetOperator(BaseOperator):
         product_set_id: str,
         product_id: str,
         location: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1182,7 +1183,7 @@ class CloudVisionRemoveProductFromProductSetOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -1241,15 +1242,15 @@ class CloudVisionDetectTextOperator(BaseOperator):
 
     def __init__(
         self,
-        image: Union[Dict, Image],
-        max_results: Optional[int] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        language_hints: Optional[Union[str, List[str]]] = None,
-        web_detection_params: Optional[Dict] = None,
-        additional_properties: Optional[Dict] = None,
+        image: dict | Image,
+        max_results: int | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        language_hints: str | list[str] | None = None,
+        web_detection_params: dict | None = None,
+        additional_properties: dict | None = None,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1266,7 +1267,7 @@ class CloudVisionDetectTextOperator(BaseOperator):
         )
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -1323,15 +1324,15 @@ class CloudVisionTextDetectOperator(BaseOperator):
 
     def __init__(
         self,
-        image: Union[Dict, Image],
-        max_results: Optional[int] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        language_hints: Optional[Union[str, List[str]]] = None,
-        web_detection_params: Optional[Dict] = None,
-        additional_properties: Optional[Dict] = None,
+        image: dict | Image,
+        max_results: int | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        language_hints: str | list[str] | None = None,
+        web_detection_params: dict | None = None,
+        additional_properties: dict | None = None,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1347,7 +1348,7 @@ class CloudVisionTextDetectOperator(BaseOperator):
         )
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -1400,13 +1401,13 @@ class CloudVisionDetectImageLabelsOperator(BaseOperator):
 
     def __init__(
         self,
-        image: Union[Dict, Image],
-        max_results: Optional[int] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        additional_properties: Optional[Dict] = None,
+        image: dict | Image,
+        max_results: int | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        additional_properties: dict | None = None,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1418,7 +1419,7 @@ class CloudVisionDetectImageLabelsOperator(BaseOperator):
         self.additional_properties = additional_properties
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -1471,13 +1472,13 @@ class CloudVisionDetectImageSafeSearchOperator(BaseOperator):
 
     def __init__(
         self,
-        image: Union[Dict, Image],
-        max_results: Optional[int] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        additional_properties: Optional[Dict] = None,
+        image: dict | Image,
+        max_results: int | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        additional_properties: dict | None = None,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1489,7 +1490,7 @@ class CloudVisionDetectImageSafeSearchOperator(BaseOperator):
         self.additional_properties = additional_properties
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -1504,8 +1505,8 @@ class CloudVisionDetectImageSafeSearchOperator(BaseOperator):
 
 
 def prepare_additional_parameters(
-    additional_properties: Optional[Dict], language_hints: Any, web_detection_params: Any
-) -> Optional[Dict]:
+    additional_properties: dict | None, language_hints: Any, web_detection_params: Any
+) -> dict | None:
     """
     Creates additional_properties parameter based on language_hints, web_detection_params and
     additional_properties parameters specified by the user
@@ -1518,14 +1519,14 @@ def prepare_additional_parameters(
 
     merged_additional_parameters = deepcopy(additional_properties)
 
-    if 'image_context' not in merged_additional_parameters:
-        merged_additional_parameters['image_context'] = {}
+    if "image_context" not in merged_additional_parameters:
+        merged_additional_parameters["image_context"] = {}
 
-    merged_additional_parameters['image_context']['language_hints'] = merged_additional_parameters[
-        'image_context'
-    ].get('language_hints', language_hints)
-    merged_additional_parameters['image_context']['web_detection_params'] = merged_additional_parameters[
-        'image_context'
-    ].get('web_detection_params', web_detection_params)
+    merged_additional_parameters["image_context"]["language_hints"] = merged_additional_parameters[
+        "image_context"
+    ].get("language_hints", language_hints)
+    merged_additional_parameters["image_context"]["web_detection_params"] = merged_additional_parameters[
+        "image_context"
+    ].get("web_detection_params", web_detection_params)
 
     return merged_additional_parameters
