@@ -16,9 +16,10 @@
 # specific language governing permissions and limitations
 # under the License.
 """MsSQL to GCS operator."""
+from __future__ import annotations
+
 import datetime
 import decimal
-from typing import Dict
 
 from airflow.providers.google.cloud.transfers.sql_to_gcs import BaseSQLToGCSOperator
 from airflow.providers.microsoft.mssql.hooks.mssql import MsSqlHook
@@ -52,11 +53,11 @@ class MSSQLToGCSOperator(BaseSQLToGCSOperator):
 
     """
 
-    ui_color = '#e0a98c'
+    ui_color = "#e0a98c"
 
-    type_map = {3: 'INTEGER', 4: 'TIMESTAMP', 5: 'NUMERIC'}
+    type_map = {3: "INTEGER", 4: "TIMESTAMP", 5: "NUMERIC"}
 
-    def __init__(self, *, mssql_conn_id='mssql_default', **kwargs):
+    def __init__(self, *, mssql_conn_id="mssql_default", **kwargs):
         super().__init__(**kwargs)
         self.mssql_conn_id = mssql_conn_id
 
@@ -72,11 +73,11 @@ class MSSQLToGCSOperator(BaseSQLToGCSOperator):
         cursor.execute(self.sql)
         return cursor
 
-    def field_to_bigquery(self, field) -> Dict[str, str]:
+    def field_to_bigquery(self, field) -> dict[str, str]:
         return {
-            'name': field[0].replace(" ", "_"),
-            'type': self.type_map.get(field[1], "STRING"),
-            'mode': "NULLABLE",
+            "name": field[0].replace(" ", "_"),
+            "type": self.type_map.get(field[1], "STRING"),
+            "mode": "NULLABLE",
         }
 
     @classmethod
