@@ -16,7 +16,9 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Campaign Manager hook."""
-from typing import Any, Dict, List, Optional, Sequence, Union
+from __future__ import annotations
+
+from typing import Any, Sequence
 
 from googleapiclient import http
 from googleapiclient.discovery import Resource, build
@@ -28,14 +30,14 @@ from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 class GoogleCampaignManagerHook(GoogleBaseHook):
     """Hook for Google Campaign Manager."""
 
-    _conn = None  # type: Optional[Resource]
+    _conn: Resource | None = None
 
     def __init__(
         self,
         api_version: str = "v3.3",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
@@ -71,7 +73,7 @@ class GoogleCampaignManagerHook(GoogleBaseHook):
         )
         return response
 
-    def insert_report(self, profile_id: str, report: Dict[str, Any]) -> Any:
+    def insert_report(self, profile_id: str, report: dict[str, Any]) -> Any:
         """
         Creates a report.
 
@@ -89,11 +91,11 @@ class GoogleCampaignManagerHook(GoogleBaseHook):
     def list_reports(
         self,
         profile_id: str,
-        max_results: Optional[int] = None,
-        scope: Optional[str] = None,
-        sort_field: Optional[str] = None,
-        sort_order: Optional[str] = None,
-    ) -> List[dict]:
+        max_results: int | None = None,
+        scope: str | None = None,
+        sort_field: str | None = None,
+        sort_order: str | None = None,
+    ) -> list[dict]:
         """
         Retrieves list of reports.
 
@@ -103,7 +105,7 @@ class GoogleCampaignManagerHook(GoogleBaseHook):
         :param sort_field: The field by which to sort the list.
         :param sort_order: Order of sorted results.
         """
-        reports: List[dict] = []
+        reports: list[dict] = []
         conn = self.get_conn()
         request = conn.reports().list(
             profileId=profile_id,
@@ -136,7 +138,7 @@ class GoogleCampaignManagerHook(GoogleBaseHook):
         )
         return response
 
-    def run_report(self, profile_id: str, report_id: str, synchronous: Optional[bool] = None) -> Any:
+    def run_report(self, profile_id: str, report_id: str, synchronous: bool | None = None) -> Any:
         """
         Runs a report.
 
@@ -203,12 +205,12 @@ class GoogleCampaignManagerHook(GoogleBaseHook):
 
     @staticmethod
     def _conversions_batch_request(
-        conversions: List[Dict[str, Any]],
+        conversions: list[dict[str, Any]],
         encryption_entity_type: str,
         encryption_entity_id: int,
         encryption_source: str,
         kind: str,
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         return {
             "kind": kind,
             "conversions": conversions,
@@ -223,7 +225,7 @@ class GoogleCampaignManagerHook(GoogleBaseHook):
     def conversions_batch_insert(
         self,
         profile_id: str,
-        conversions: List[Dict[str, Any]],
+        conversions: list[dict[str, Any]],
         encryption_entity_type: str,
         encryption_entity_id: int,
         encryption_source: str,
@@ -258,8 +260,8 @@ class GoogleCampaignManagerHook(GoogleBaseHook):
             )
             .execute(num_retries=self.num_retries)
         )
-        if response.get('hasFailures', False):
-            errored_conversions = [stat['errors'] for stat in response['status'] if 'errors' in stat]
+        if response.get("hasFailures", False):
+            errored_conversions = [stat["errors"] for stat in response["status"] if "errors" in stat]
             if len(errored_conversions) > max_failed_inserts:
                 raise AirflowException(errored_conversions)
         return response
@@ -267,7 +269,7 @@ class GoogleCampaignManagerHook(GoogleBaseHook):
     def conversions_batch_update(
         self,
         profile_id: str,
-        conversions: List[Dict[str, Any]],
+        conversions: list[dict[str, Any]],
         encryption_entity_type: str,
         encryption_entity_id: int,
         encryption_source: str,
@@ -302,8 +304,8 @@ class GoogleCampaignManagerHook(GoogleBaseHook):
             )
             .execute(num_retries=self.num_retries)
         )
-        if response.get('hasFailures', False):
-            errored_conversions = [stat['errors'] for stat in response['status'] if 'errors' in stat]
+        if response.get("hasFailures", False):
+            errored_conversions = [stat["errors"] for stat in response["status"] if "errors" in stat]
             if len(errored_conversions) > max_failed_updates:
                 raise AirflowException(errored_conversions)
         return response
