@@ -16,7 +16,9 @@
 # specific language governing permissions and limitations
 # under the License.
 """Hook for Google Drive service"""
-from typing import IO, Any, Optional, Sequence, Union
+from __future__ import annotations
+
+from typing import IO, Any, Sequence
 
 from googleapiclient.discovery import Resource, build
 from googleapiclient.http import HttpRequest, MediaFileUpload
@@ -43,14 +45,14 @@ class GoogleDriveHook(GoogleBaseHook):
         account from the list granting this role to the originating account.
     """
 
-    _conn = None  # type: Optional[Resource]
+    _conn: Resource | None = None
 
     def __init__(
         self,
         api_version: str = "v3",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
@@ -122,15 +124,14 @@ class GoogleDriveHook(GoogleBaseHook):
 
         :param file_id: The Google Drive file id
         :return: request
-        :rtype: HttpRequest
         """
         service = self.get_conn()
         request = service.files().get_media(fileId=file_id)
         return request
 
     def exists(
-        self, folder_id: str, file_name: str, drive_id: Optional[str] = None, *, include_trashed: bool = True
-    ):
+        self, folder_id: str, file_name: str, drive_id: str | None = None, *, include_trashed: bool = True
+    ) -> bool:
         """
         Checks to see if a file exists within a Google Drive folder
 
@@ -140,7 +141,6 @@ class GoogleDriveHook(GoogleBaseHook):
         :param include_trashed: Whether to include objects in trash or not, default True as in Google API.
 
         :return: True if the file exists, False otherwise
-        :rtype: bool
         """
         return bool(
             self.get_file_id(
@@ -149,8 +149,8 @@ class GoogleDriveHook(GoogleBaseHook):
         )
 
     def get_file_id(
-        self, folder_id: str, file_name: str, drive_id: Optional[str] = None, *, include_trashed: bool = True
-    ):
+        self, folder_id: str, file_name: str, drive_id: str | None = None, *, include_trashed: bool = True
+    ) -> dict:
         """
         Returns the file id of a Google Drive file
 
@@ -160,7 +160,6 @@ class GoogleDriveHook(GoogleBaseHook):
         :param include_trashed: Whether to include objects in trash or not, default True as in Google API.
 
         :return: Google Drive file id if the file exists, otherwise None
-        :rtype: str if file exists else None
         """
         query = f"name = '{file_name}'"
         if folder_id:
@@ -192,8 +191,8 @@ class GoogleDriveHook(GoogleBaseHook):
                 .execute(num_retries=self.num_retries)
             )
         file_metadata = {}
-        if files['files']:
-            file_metadata = {"id": files['files'][0]['id'], "mime_type": files['files'][0]['mimeType']}
+        if files["files"]:
+            file_metadata = {"id": files["files"][0]["id"], "mime_type": files["files"][0]["mimeType"]}
         return file_metadata
 
     def upload_file(
@@ -216,7 +215,6 @@ class GoogleDriveHook(GoogleBaseHook):
         :param resumable: True if this is a resumable upload. False means upload
             in a single request.
         :return: File ID
-        :rtype: str
         """
         service = self.get_conn()
         directory_path, _, file_name = remote_location.rpartition("/")
