@@ -15,12 +15,13 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
 import ast
 import json
 import socket
 import time
-from typing import Any, Dict, Iterable, List, Mapping, Optional, Sequence, Union
+from typing import Any, Iterable, List, Mapping, Sequence, Union
 from urllib.error import HTTPError, URLError
 
 import jenkins
@@ -32,10 +33,10 @@ from airflow.models import BaseOperator
 from airflow.providers.jenkins.hooks.jenkins import JenkinsHook
 
 JenkinsRequest = Mapping[str, Any]
-ParamType = Optional[Union[str, Dict, List]]
+ParamType = Union[str, dict, List, None]
 
 
-def jenkins_request_with_headers(jenkins_server: Jenkins, req: Request) -> Optional[JenkinsRequest]:
+def jenkins_request_with_headers(jenkins_server: Jenkins, req: Request) -> JenkinsRequest | None:
     """
     We need to get the headers in addition to the body answer
     to get the location from them
@@ -55,19 +56,19 @@ def jenkins_request_with_headers(jenkins_server: Jenkins, req: Request) -> Optio
             raise jenkins.EmptyResponseException(
                 f"Error communicating with server[{jenkins_server.server}]: empty response"
             )
-        return {'body': response_body.decode('utf-8'), 'headers': response_headers}
+        return {"body": response_body.decode("utf-8"), "headers": response_headers}
     except HTTPError as e:
         # Jenkins's funky authentication means its nigh impossible to distinguish errors.
         if e.code in [401, 403, 500]:
-            raise JenkinsException(f'Error in request. Possibly authentication failed [{e.code}]: {e.reason}')
+            raise JenkinsException(f"Error in request. Possibly authentication failed [{e.code}]: {e.reason}")
         elif e.code == 404:
-            raise jenkins.NotFoundException('Requested item could not be found')
+            raise jenkins.NotFoundException("Requested item could not be found")
         else:
             raise
     except socket.timeout as e:
-        raise jenkins.TimeoutException(f'Error in request: {e}')
+        raise jenkins.TimeoutException(f"Error in request: {e}")
     except URLError as e:
-        raise JenkinsException(f'Error in request: {e.reason}')
+        raise JenkinsException(f"Error in request: {e.reason}")
     return None
 
 
@@ -89,9 +90,9 @@ class JenkinsJobTriggerOperator(BaseOperator):
     :param allowed_jenkins_states: Iterable of allowed result jenkins states, default is ``['SUCCESS']``
     """
 
-    template_fields: Sequence[str] = ('parameters',)
-    template_ext: Sequence[str] = ('.json',)
-    ui_color = '#f9ec86'
+    template_fields: Sequence[str] = ("parameters",)
+    template_ext: Sequence[str] = (".json",)
+    ui_color = "#f9ec86"
 
     def __init__(
         self,
@@ -101,7 +102,7 @@ class JenkinsJobTriggerOperator(BaseOperator):
         parameters: ParamType = None,
         sleep_time: int = 10,
         max_try_before_job_appears: int = 10,
-        allowed_jenkins_states: Optional[Iterable[str]] = None,
+        allowed_jenkins_states: Iterable[str] | None = None,
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -110,9 +111,9 @@ class JenkinsJobTriggerOperator(BaseOperator):
         self.sleep_time = max(sleep_time, 1)
         self.jenkins_connection_id = jenkins_connection_id
         self.max_try_before_job_appears = max_try_before_job_appears
-        self.allowed_jenkins_states = list(allowed_jenkins_states) if allowed_jenkins_states else ['SUCCESS']
+        self.allowed_jenkins_states = list(allowed_jenkins_states) if allowed_jenkins_states else ["SUCCESS"]
 
-    def build_job(self, jenkins_server: Jenkins, params: ParamType = None) -> Optional[JenkinsRequest]:
+    def build_job(self, jenkins_server: Jenkins, params: ParamType = None) -> JenkinsRequest | None:
         """
         This function makes an API call to Jenkins to trigger a build for 'job_name'
         It returned a dict with 2 keys : body and headers.
@@ -129,7 +130,7 @@ class JenkinsJobTriggerOperator(BaseOperator):
         if params and isinstance(params, str):
             params = ast.literal_eval(params)
 
-        request = Request(method='POST', url=jenkins_server.build_job_url(self.job_name, params, None))
+        request = Request(method="POST", url=jenkins_server.build_job_url(self.job_name, params, None))
         return jenkins_request_with_headers(jenkins_server, request)
 
     def poll_job_in_queue(self, location: str, jenkins_server: Jenkins) -> int:
@@ -148,32 +149,32 @@ class JenkinsJobTriggerOperator(BaseOperator):
         :return: The build_number corresponding to the triggered job
         """
         try_count = 0
-        location += '/api/json'
+        location += "/api/json"
         # TODO Use get_queue_info instead
         # once it will be available in python-jenkins (v > 0.4.15)
-        self.log.info('Polling jenkins queue at the url %s', location)
+        self.log.info("Polling jenkins queue at the url %s", location)
         while try_count < self.max_try_before_job_appears:
             try:
                 location_answer = jenkins_request_with_headers(
-                    jenkins_server, Request(method='POST', url=location)
+                    jenkins_server, Request(method="POST", url=location)
                 )
             # we don't want to fail the operator, this will continue to poll
             # until max_try_before_job_appears reached
             except (HTTPError, JenkinsException):
-                self.log.warning('polling failed, retrying', exc_info=True)
+                self.log.warning("polling failed, retrying", exc_info=True)
                 try_count += 1
                 time.sleep(self.sleep_time)
                 continue
 
             if location_answer is not None:
-                json_response = json.loads(location_answer['body'])
+                json_response = json.loads(location_answer["body"])
                 if (
-                    'executable' in json_response
-                    and json_response['executable'] is not None
-                    and 'number' in json_response['executable']
+                    "executable" in json_response
+                    and json_response["executable"] is not None
+                    and "number" in json_response["executable"]
                 ):
-                    build_number = json_response['executable']['number']
-                    self.log.info('Job executed on Jenkins side with the build number %s', build_number)
+                    build_number = json_response["executable"]["number"]
+                    self.log.info("Job executed on Jenkins side with the build number %s", build_number)
                     return build_number
             try_count += 1
             time.sleep(self.sleep_time)
@@ -186,9 +187,9 @@ class JenkinsJobTriggerOperator(BaseOperator):
         """Instantiate jenkins hook"""
         return JenkinsHook(self.jenkins_connection_id)
 
-    def execute(self, context: Mapping[Any, Any]) -> Optional[str]:
+    def execute(self, context: Mapping[Any, Any]) -> str | None:
         self.log.info(
-            'Triggering the job %s on the jenkins : %s with the parameters : %s',
+            "Triggering the job %s on the jenkins : %s with the parameters : %s",
             self.job_name,
             self.jenkins_connection_id,
             self.parameters,
@@ -196,7 +197,7 @@ class JenkinsJobTriggerOperator(BaseOperator):
         jenkins_server = self.get_hook().get_jenkins_server()
         jenkins_response = self.build_job(jenkins_server, self.parameters)
         if jenkins_response:
-            build_number = self.poll_job_in_queue(jenkins_response['headers']['Location'], jenkins_server)
+            build_number = self.poll_job_in_queue(jenkins_response["headers"]["Location"], jenkins_server)
 
         time.sleep(self.sleep_time)
         keep_polling_job = True
@@ -205,30 +206,30 @@ class JenkinsJobTriggerOperator(BaseOperator):
         while keep_polling_job:
             try:
                 build_info = jenkins_server.get_build_info(name=self.job_name, number=build_number)
-                if build_info['result'] is not None:
+                if build_info["result"] is not None:
                     keep_polling_job = False
                     # Check if job ended with not allowed state.
-                    if build_info['result'] not in self.allowed_jenkins_states:
+                    if build_info["result"] not in self.allowed_jenkins_states:
                         raise AirflowException(
                             f"Jenkins job failed, final state : {build_info['result']}. "
                             f"Find more information on job url : {build_info['url']}"
                         )
                 else:
-                    self.log.info('Waiting for job to complete : %s , build %s', self.job_name, build_number)
+                    self.log.info("Waiting for job to complete : %s , build %s", self.job_name, build_number)
                     time.sleep(self.sleep_time)
             except jenkins.NotFoundException as err:
 
-                raise AirflowException(f'Jenkins job status check failed. Final error was: {err.resp.status}')
+                raise AirflowException(f"Jenkins job status check failed. Final error was: {err.resp.status}")
             except jenkins.JenkinsException as err:
                 raise AirflowException(
-                    f'Jenkins call failed with error : {err}, if you have parameters '
-                    'double check them, jenkins sends back '
-                    'this exception for unknown parameters'
-                    'You can also check logs for more details on this exception '
-                    '(jenkins_url/log/rss)'
+                    f"Jenkins call failed with error : {err}, if you have parameters "
+                    "double check them, jenkins sends back "
+                    "this exception for unknown parameters"
+                    "You can also check logs for more details on this exception "
+                    "(jenkins_url/log/rss)"
                 )
         if build_info:
             # If we can we return the url of the job
             # for later use (like retrieving an artifact)
-            return build_info['url']
+            return build_info["url"]
         return None
