@@ -76,6 +76,8 @@ REVISION_HEADS_MAP = {
     "2.4.2": "b0d31815b5a6",
     "2.4.3": "e07f49787c9d",
     "2.5.0": "290244fb8b83",
+    "2.5.1": "290244fb8b83",
+    "2.5.2": "290244fb8b83",
 }
 
 
@@ -1570,7 +1572,7 @@ def upgradedb(
         log.info("Creating tables")
         val = os.environ.get("AIRFLOW__DATABASE__SQL_ALCHEMY_MAX_SIZE")
         try:
-            # Reconfigure the ORM ot use _EXACTLY_ one connection, otherwise some db engines hang forever
+            # Reconfigure the ORM to use _EXACTLY_ one connection, otherwise some db engines hang forever
             # trying to ALTER TABLEs
             os.environ["AIRFLOW__DATABASE__SQL_ALCHEMY_MAX_SIZE"] = "1"
             settings.reconfigure_orm(pool_class=sqlalchemy.pool.SingletonThreadPool)
