@@ -1,4 +1,4 @@
-#!/usr/bin/env python3
+#!/usr/bin/env python
 
 # Licensed to the Apache Software Foundation (ASF) under one
 # or more contributor license agreements.  See the NOTICE file
@@ -21,9 +21,12 @@ from __future__ import annotations
 import argparse
 import os
 
-from docs.exts.docs_build.docs_builder import AirflowDocsBuilder
-from docs.exts.docs_build.package_filter import process_package_filters
-from docs.exts.provider_yaml_utils import load_package_data
+# isort:off (needed to workaround isort bug)
+from exts.docs_build.docs_builder import AirflowDocsBuilder
+from exts.docs_build.package_filter import process_package_filters
+from exts.provider_yaml_utils import load_package_data
+
+# isort:on (needed to workaround isort bug)
 
 AIRFLOW_SITE_DIR = os.environ.get("AIRFLOW_SITE_DIRECTORY")
 
